<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://xfinitysoft.com
 * @since      1.0.0
 *
 * @package    catalog_mode_woocommerce
 * @subpackage catalog_mode_woocommerce/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    catalog_mode_woocommerce
 * @subpackage catalog_mode_woocommerce/admin
 * @author     Xfinitysoft <support@xfinitysoft.com>
 */
class catalog_mode_woocommerce_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $catalog_mode_woocommerce    The ID of this plugin.
	 */
	private $catalog_mode_woocommerce;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $catalog_mode_woocommerce       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $catalog_mode_woocommerce, $version ) {

		$this->catalog_mode_woocommerce = $catalog_mode_woocommerce;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in catalog_mode_woocommerce_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The catalog_mode_woocommerce_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
        wp_enqueue_style( 'select2', plugin_dir_url( __FILE__ ) . 'css/select2.min.css');
        wp_enqueue_style( 'wp-color-picker' );
		wp_enqueue_style( $this->catalog_mode_woocommerce, plugin_dir_url( __FILE__ ) . 'css/catalog-mode-woocommerce-admin.css', array(), $this->version, 'all' );


	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in catalog_mode_woocommerce_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The catalog_mode_woocommerce_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
        wp_enqueue_script( 'select2', plugin_dir_url( __FILE__ ) . 'js/select2.full.min.js');
        wp_enqueue_script('fontawesome','https://kit.fontawesome.com/ae3885a094.js');
		wp_enqueue_script( $this->catalog_mode_woocommerce, plugin_dir_url( __FILE__ ) . 'js/catalog-mode-woocommerce-admin.js', array( 'jquery','wp-color-picker'), $this->version, false );
        $script_vars = $this->xscmw_get_script_vars();
        wp_localize_script($this->catalog_mode_woocommerce, 'xscmw_script_vars', $script_vars );

	}

    /**
     * Add the Menu in the admin area.
     *
     * @since    1.0.0
     */
    public function xscmw_add_menu(){
        add_menu_page(esc_html__('Catalog Mode','catalog-mode-woocommerce'),esc_html__('Catalog Mode','catalog-mode-woocommerce'),'manage_options','catalog_mode','','',40);
        add_submenu_page( 'catalog_mode', esc_html__('Settings','catalog-mode-woocommerce'), esc_html__('Settings','catalog-mode-woocommerce'),'manage_options', 'catalog_mode', array($this, 'xscmw_catalog_mode_callback_setting'),41);
        add_submenu_page( 'catalog_mode', esc_html__('Exclusion List','catalog-mode-woocommerce'), esc_html__('Exclusion List','catalog-mode-woocommerce'),'manage_options', 'exclusion_list', array($this, 'xscmw_catalog_mode_callback_exclusion'),42);
        add_submenu_page( 'catalog_mode', esc_html__('Inquiry','catalog-mode-woocommerce'), esc_html__('Inquiry','catalog-mode-woocommerce'),'manage_options', 'xscmw_inquiry', array($this, 'xscmw_catalog_mode_callback_inquiry'),43);
        add_submenu_page( 'catalog_mode', esc_html__('Buttons & Labels','catalog-mode-woocommerce'), esc_html__('Buttons & Labels','catalog-mode-woocommerce'),'manage_options', 'edit.php?post_type=xscmw-button-label');

    }

    /**
    * create post type
    * @since    1.0.0
    */

    public function xscmw_create_post_type(){
        register_post_type( 'xscmw-button-label',
            array(
                'labels' => array(
                    'name'                  => esc_html__( 'Buttons & Labels', 'catalog_mode_woocommerce'),
                    'singular_name'         => esc_html__( 'button or label', 'catalog_mode_woocommerce'),
                    'menu_name'             => _x( 'Buttons & Labels', 'Admin menu name', 'catalog_mode_woocommerce' ),
                    'all_items'             => __( 'Buttons & Labels', 'catalog_mode_woocommerce' ),
                    'add_new'               => __( 'Create a new button or label', 'catalog_mode_woocommerce' ),
                    'add_new_item'          => __( 'Create a new button or label', 'catalog_mode_woocommerce' ),
                    'edit'                  => __( 'Edit', 'catalog_mode_woocommerce' ),
                    'edit_item'             => __( 'Edit button or label', 'catalog_mode_woocommerce' ),
                    'new_item'              => __( 'Add button or label', 'catalog_mode_woocommerce' ),
                    'search_items'          => __( 'Search button or label', 'catalog_mode_woocommerce' ),
                    'not_found'             => esc_html__('No button or label found', 'catalog_mode_woocommerce'),
                    'not_found_in_trash'    => esc_html__('No button or label found in trash', 'catalog_mode_woocommerce'),
                ),
                'public'                => true,
                'supports'              => array('title'),
                'show_ui'               => true,
                'capability_type'       => 'post',
                'show_in_menu'          => false,
                'map_meta_cap'          => true,
                'publicly_queryable'    => true,
                'exclude_from_search'   => false,
                'hierarchical'          => false,
                'rewrite'               => array('slug' => 'xscmw-button-label', 'with_front' => true),
                'query_var'             => false,
                'has_archive'           => 'false',
     
            )
        );
    }

    /**
    * Display settings page
    * @since    1.0.0
    */

    public function xscmw_catalog_mode_callback_setting(){
        include_once plugin_dir_path( __FILE__ ) . 'partials/catalog-mode-woocommerce-admin-setting.php';
    }

    /**
    * Display exclusion page
    * @since    1.0.0
    */

    public function xscmw_catalog_mode_callback_exclusion(){
        $exclusionListTable = new XSCMW_EXCLUSION_TABLE();
        $products = wc_get_products( array( 'status' => 'publish', 'limit' => -1 ) );
        $categories = get_terms('product_cat');
        $tags = get_terms('product_tag');
        include_once plugin_dir_path( __FILE__ ) . 'partials/catalog-mode-woocommerce-admin-exclusion.php';
    }
        /**
    * Display settings page
    * @since    1.0.0
    */

    public function xscmw_catalog_mode_callback_inquiry(){
        include_once plugin_dir_path( __FILE__ ) . 'partials/catalog-mode-woocommerce-admin-inquiry.php';
    }
        /**
    * Display settings page
    * @since    1.0.0
    */

    public function xscmw_catalog_mode_callback_button_labels(){
        include_once plugin_dir_path( __FILE__ ) . 'partials/catalog-mode-woocommerce-admin-button-labels.php';
    }

    /**
    * Register the setting Fields options
    * @param NULL
    * @return NULL
    **/
    public function xscmw_register_settings(){
        register_setting( 'xscmw_settings' , 'xscmw_setting' );
        register_setting( 'xscmw_inquiry_forms','xscmw_inquiry_form');
    }

    public function xscmw_add_new_exclusion(){
        $data = array();
        parse_str($_POST['data'], $data);
        $item_type = $data['item-type'];
        unset($data['item-type']);
        $exclusion_data = array();
        foreach ($data as $key => $value) {
            if(is_array($value)){
                $item_ids = array_map('esc_html', $value);
            }else{
                $exclusion_data[$key] = $value;
            }
        }
        if($item_type == 'product'){
            foreach ($item_ids as $id) {
               $response = update_post_meta($id,'xscmw_exclusions',$exclusion_data);
            }
        }else{
            foreach ($item_ids as $id) {
               $response = update_term_meta($id,'xscmw_exclusions',$exclusion_data);
            }
        }
        if($response){
            $message = array('message' => 'Exclusion saved Successfully' , 'status' => '1');
        }else{
            $message = array('message' => 'Exclusion not save' , 'status' => '0');
        }
        wp_send_json($message);
        wp_die();
    }

    public function xscmw_get_script_vars(){
        $script_var=array(
                'ajax_url'       => admin_url('admin-ajax.php'),
                'contact_form_7' => $this->get_contact_forms(),
                'ninja_form'     => $this->get_ninja_forms(),
                );
        return  $script_var;
    }

    public function get_contact_forms(){
        global $wpdb;
        $form_query = "SELECT ID as id, post_title as text FROM {$wpdb->prefix}posts
                          WHERE post_status='publish' AND post_type='wpcf7_contact_form'
                          ORDER BY post_title";
        $xscmw_forms = $wpdb->get_results($form_query, ARRAY_A);
        return $xscmw_forms;               
    }

    public function get_ninja_forms(){
        if(is_plugin_active('ninja-forms/ninja-forms.php')){
            global $wpdb;
            $form_query = "SELECT id as id, form_title as text FROM {$wpdb->prefix}nf3_forms ORDER BY form_title";
            $xscmw_forms = $wpdb->get_results($form_query, ARRAY_A);
            return $xscmw_forms;   
        }
    }
    public function xscmw_admin_button_edit(){
        $screen = get_current_screen();
        if(is_admin()){
            if( 'edit-xscmw-button-label' === $screen->id || 'xscmw-button-label' === $screen->id){
                // Before:
                add_action( 'all_admin_notices',array($this,'xscmw_catalog_mode_callback_button_labels'));

                // After:
                add_action( 'in_admin_footer', function(){
                    echo '</div></div>';
                });
            }
        }
    }

    public function xscmw_add_meta_boxes($post_type, $post){
        if($post_type=="xscmw-button-label"){
            add_meta_box( 
                'xscmw-button-meta-box',
                __( ' ' ),
                array($this,'xscmw_render_button_meta'),
                $post_type,
                'normal',
                'default'
            );
        }

    }

    public function xscmw_render_button_meta(){
        global $post;
        $settings = get_post_meta($post->ID,'xscmw_button_form',true);
        include_once plugin_dir_path( __FILE__ ) . 'partials/catalog-mode-woocommerce-meta-button-labels.php';
    }

    public function xscmw_save_label_post($post_id,$post){
        if (isset($_REQUEST['bulk_edit']))
            return;
        if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ){
            return;
        }
        if($post->post_type = "xscmw-button-label"){
            $data = isset( $_POST['xscmw_button_form'] ) ? (array) $_POST['xscmw_button_form'] : array();
            update_post_meta($post_id,'xscmw_button_form',$data);
        }
        
    }
}
