<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://xfinitysoft.com
 * @since      1.0.0
 *
 * @package    catalog_mode_woocommerce
 * @subpackage catalog_mode_woocommerce/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    catalog_mode_woocommerce
 * @subpackage catalog_mode_woocommerce/admin
 * @author     Xfinitysoft <support@xfinitysoft.com>
 */
class XSCMW_EXCLUSION_TABLE extends WP_List_Table {
    var $exclusion_list;
    /** Class constructor */
    public function __construct() {
        parent::__construct( [
            'singular' => __( 'EXCLUSION LIST', 'catalog-mode-woocommerce' ), //singular name of the listed records
            'plural'   => __( 'EXCLUSION LISTs', 'catalog-mode-woocommerce' ), //plural name of the listed records
            'ajax'     => false //should this table support ajax?

        ] );
        global $wpdb;
        $form_setting = get_option('xscmw_inquiry_form',true);
        $term_arg = array(
            'taxonomy' => 'product_cat', 
            'hide_empty' => false ,  
            'meta_query' => array( 
                array('key' => 'xscmw_exclusions', 
                    'value' => '',
                    'compare'   => '!='
                )
            )
        );
        $terms = get_terms( $term_arg );
        if( is_array($terms) && !empty($terms) ){
            foreach ( $terms as $term) {
                $value = get_term_meta($term->term_id,'xscmw_exclusions',true);
                $id = $term->term_id;
                $item_name = $term->name;
                $add_to_cart = $value['set_add_cart'];
                if($add_to_cart == 'hidden'){
                    $add_to_cart .= $value['replace-cart-product-page'] == 'none'? '' : ' <br> Replaced with '.get_the_title($value['replace-cart-product-page']). ' in  product page';
                    $add_to_cart .= $value['replace-cart-shop-page'] == 'none'? '' : ' <br> Replaced with '.get_the_title($value['replace-cart-shop-page']). ' in  shop page';
                }
                $price = $value['set_price'];
                if($price == 'hidden'){
                   $price .= $value['replace-price'] == 'none'? '' : ' <br> Replaced with '.get_the_title($value['replace-price']); 
                }
                if(!isset($form_setting['set-form']) || $form_setting['set-form'] =='hidden_all'){
                    $inquiry_form = 'off';
                }else{
                    $inquiry_form = isset($value['inquiry_form']) ? 'on' :'off';
                }
                
                $this->exclusion_list[] = array('ID' => $id ,'item_name' => $item_name, 'item_type' => 'Categories',
                'add_to_cart' => $add_to_cart , 'price'=>$price , 'inquiry_form'=> $inquiry_form );
            }
        }
        $args = array(
            'post_type' => 'product',
            'post_status' => 'publish',
            'posts_per_page' => -1,
            'meta_key' => 'xscmw_exclusions'
        );
        $dbResult = new WP_Query($args);
        global $post;
        while($dbResult->have_posts()){
            $dbResult->the_post();
            $value = get_post_meta($post->ID,'xscmw_exclusions',true);
            $id = $post->ID;
            $item_name = $post->post_title;
            $add_to_cart = $value['set_add_cart'];
            if($add_to_cart == 'hidden'){
                $add_to_cart .= $value['replace-cart-product-page'] == 'none'? '' : ' <br> Replaced with '.get_the_title($value['replace-cart-product-page']). ' in  product page';
                $add_to_cart .= $value['replace-cart-shop-page'] == 'none'? '' : ' <br> Replaced with '.get_the_title($value['replace-cart-shop-page']). ' in  shop page';
            }
            $price = $value['set_price'];
            if($price == 'hidden'){
               $price .= $value['replace-price'] == 'none'? '' : ' <br> Replaced with '.get_the_title($value['replace-price']); 
            }
            if(!isset($form_setting['set-form']) || $form_setting['set-form'] =='hidden_all'){
                $inquiry_form = 'off';
            }else{
                $inquiry_form = isset($value['inquiry_form']) ? 'on' :'off';
            }
            $this->exclusion_list[] = array('ID' => $id ,'item_name' => $item_name, 'item_type' => 'Product',
            'add_to_cart' => $add_to_cart , 'price'=>$price , 'inquiry_form'=> $inquiry_form );
        }
        $term_arg['taxonomy'] = 'product_tag';
        $terms = get_terms($term_arg);
        if( is_array($terms) && !empty($terms) ){
            foreach ( $terms as $term) {
                $value = get_term_meta($term->term_id,'xscmw_exclusions',true);
                $id = $term->term_id;
                $item_name = $term->name;
                $add_to_cart = $value['set_add_cart'];
                if($add_to_cart == 'hidden'){
                    $add_to_cart .= $value['replace-cart-product-page'] == 'none'? '' : ' <br> Replaced with '.get_the_title($value['replace-cart-product-page']). ' in  product page';
                    $add_to_cart .= $value['replace-cart-shop-page'] == 'none'? '' : ' <br> Replaced with '.get_the_title($value['replace-cart-shop-page']). ' in  shop page';
                }
                $price = $value['set_price'];
                if($price == 'hidden'){
                   $price .= $value['replace-price'] == 'none'? '' : ' <br> Replaced with '.get_the_title($value['replace-price']); 
                }
                $inquiry_form = isset($value['inquiry_form'])? 'on' :'off';
                $this->exclusion_list[] = array('ID' => $id ,'item_name' => $item_name, 'item_type' => 'Tags',
                'add_to_cart' => $add_to_cart , 'price'=>$price , 'inquiry_form'=> $inquiry_form );
            }
        }
        if(!empty($this->exclusion_list)){
            $key  = array_column($this->exclusion_list, 'item_name');
            if(isset($_GET['order']) && $_GET['order'] == 'desc'){
                array_multisort($key,SORT_DESC,SORT_STRING,$this->exclusion_list);
            }else{
                array_multisort($key,SORT_ASC,SORT_STRING,$this->exclusion_list);
            } 
        }
        
        
        
    }

    function get_columns(){
      $columns = array(
        'cb'          => '<input type="checkbox" />',
        'item_name'   => 'Item Name',
        'item_type'   => 'Item Type',
        'add_to_cart' => 'Add to cart',
        'price'       => 'Price',
        'inquiry_form'=> 'Inquiry Form'
      );
      return $columns;
    }

    function prepare_items() {
        $columns = $this->get_columns();
        $hidden = array();
        $sortable = $this->get_sortable_columns();
        $this->_column_headers = array($columns, $hidden, $sortable);
        $this->process_bulk_action();
        $per_page     = $this->get_items_per_page( 'Exclusion_per_page', 10 );
        $current_page = $this->get_pagenum();

        $total_items  = !empty($this->exclusion_list)?count($this->exclusion_list):0;
        $this->set_pagination_args( [
        'total_items' => $total_items, //WE have to calculate the total number of items
        'per_page'    => $per_page //WE have to determine how many items to show on a page
        ] );
        $this->items = $this->xscmw_exclusion_list($per_page,$current_page);
    }

    function column_default( $item, $column_name ) {
        switch( $column_name ) { 
            case 'item_name':
            case 'item_type':
            case 'add_to_cart':
            case 'price':
            case 'inquiry_form':
                return $item[ $column_name ];
            default:
                return print_r( $item, true );
        }
    }
    /** Text displayed when no customer data is available */
    public function no_items() {
        esc_html_e( 'No exclusion avaliable.', 'catalog-mode-woocommerce' );
    }

    /**
     * Method for name column
     *
     * @param array $item an array of DB data
     *
     * @return string
     */
    function column_item_name( $item ) {

        // create a nonce
        $delete_nonce = wp_create_nonce( 'xscmw_delete_exclusion' );

        $title = '#'.$item['ID'].' ' . $item['item_name'];

        $actions = [
        'edit_exclusion' => sprintf( '<a href="?page=%s&tab=%s&id=%s&_wpnonce=%s&item_type=%s">Edit exculsion</a>', esc_attr( $_REQUEST['page'] ), 'single_exclusion', absint( $item['ID'] ), $delete_nonce,$item['item_type']),
        'delete' => sprintf( '<a href="?page=%s&action=%s&id=%s&_wpnonce=%s&item_type=%s">Remove from list</a>', esc_attr( $_REQUEST['page'] ), 'delete', absint( $item['ID'] ), $delete_nonce,$item['item_type'])
        ];

        return $title . $this->row_actions( $actions );
    }

    /**
     * Render the bulk edit checkbox
     *
     * @param array $item
     *
     * @return string
     */
    function column_cb( $item ) {
          return sprintf(
            '<input type="checkbox" name="bulk-delete[%s][]" value="%s" />',$item['item_type'],$item['ID']
          );
    }

    public function xscmw_exclusion_list($per_page = 10, $page_number = 1){
        if(!empty($this->exclusion_list)){
            $exclusion_items = array_chunk($this->exclusion_list, $per_page);
            return  $exclusion_items[$page_number-1];
        }else{
            return array();
        }
        
    }
    /**
     * Columns to make sortable.
     *
     * @return array
     */
    public function get_sortable_columns() {
        $sortable_columns = array(
        'item_name' => array( 'item_name', true )
        );

        return $sortable_columns;
    }

    /**
     * Returns an associative array containing the bulk action
     *
     * @return array
     */
    public function get_bulk_actions() {
        $actions = [
        'bulk-delete' => 'Remove from list'
        ];

        return $actions;
    }

    public function process_bulk_action() {

        //Detect when a bulk action is being triggered...
        if ( 'delete' === $this->current_action() ) {

            // In our file that handles the request, verify the nonce.
            $nonce = esc_attr( $_REQUEST['_wpnonce'] );

            if ( ! wp_verify_nonce( $nonce, 'xscmw_delete_exclusion' ) ) {
                die( 'Go get a life script kiddies' );
            }
            else {
                if(isset($_GET['item_type'])){
                    if($_GET['item_type'] == 'Product'){
                        delete_post_meta($_GET['id'],'xscmw_exclusions');
                    }else{
                        delete_term_meta($_GET['id'],'xscmw_exclusions');
                    }
                }
                wp_redirect( esc_url( add_query_arg() ) );
                exit;
            }

        }

            // If the delete bulk action is triggered
        if ( ( isset( $_POST['action'] ) && $_POST['action'] == 'bulk-delete' )
           || ( isset( $_POST['action2'] ) && $_POST['action2'] == 'bulk-delete' )
        ) {
            $delete_ids = esc_sql( $_POST['bulk-delete'] );
            foreach ( $delete_ids as $key => $ids){
                foreach($ids as $id){
                    if($key == 'Product'){
                        delete_post_meta($id,'xscmw_exclusions');
                    }else{
                        delete_term_meta($id,'xscmw_exclusions');
                    }
                }
            }

            wp_redirect( esc_url( add_query_arg() ) );
            exit;
        }
    }

} 
?>