<?php

/**
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              http://www.xfinitysoft.com
 * @since             1.0.0
 * @package           catalog-mode-woocommerce
 *
 * @wordpress-plugin
 * Plugin Name:       Catalog Mode for Woocommerce
 * Description:       <code><strong>Catalog Mode for Woocommere</strong></code> allows hiding product prices, cart and checkout from your store and turning it into a performing product catalogue. You will be able to adjust your catalogue settings as you prefer based on your requirements.
 * Version:           1.0.0
 * Author:            Xfinitysoft
 * Author URI:        http://www.xfinitysoft.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       catalog-mode-woocommerce
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 */
define( 'catalog_mode_woocommerce_VERSION', '1.0.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-catalog-mode-woocommerce-activator.php
 */
function activate_catalog_mode_woocommerce() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-catalog-mode-woocommerce-activator.php';
	catalog_mode_woocommerce_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-catalog-mode-woocommerce-deactivator.php
 */
function deactivate_catalog_mode_woocommerce() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-catalog-mode-woocommerce-deactivator.php';
	catalog_mode_woocommerce_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_catalog_mode_woocommerce' );
register_deactivation_hook( __FILE__, 'deactivate_catalog_mode_woocommerce' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-catalog-mode-woocommerce.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_catalog_mode_woocommerce() {

	$plugin = new catalog_mode_woocommerce();
	$plugin->run();

}
run_catalog_mode_woocommerce();
