<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://xfinitysoft.com
 * @since      1.0.0
 *
 * @package    catalog_mode_woocommerce
 * @subpackage catalog_mode_woocommerce/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    catalog_mode_woocommerce
 * @subpackage catalog_mode_woocommerce/public
 * @author     Xfinitysoft <support@xfinitysoft.com>
 */
class catalog_mode_woocommerce_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $catalog_mode_woocommerce    The ID of this plugin.
	 */
	private $catalog_mode_woocommerce;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $catalog_mode_woocommerce       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $catalog_mode_woocommerce, $version ) {

		$this->catalog_mode_woocommerce = $catalog_mode_woocommerce;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in catalog_mode_woocommerce_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The catalog_mode_woocommerce_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
        wp_enqueue_script('fontawesome','https://kit.fontawesome.com/ae3885a094.js');
		wp_enqueue_style( $this->catalog_mode_woocommerce, plugin_dir_url( __FILE__ ) . 'css/catalog-mode-woocommerce-public.css', array(), $this->version, 'all' );

        /*wp_add_inline_style()*/

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in catalog_mode_woocommerce_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The catalog_mode_woocommerce_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->catalog_mode_woocommerce, plugin_dir_url( __FILE__ ) . 'js/catalog-mode-woocommerce-public.js', array( 'jquery' ), $this->version, false );

	}
    
    public function xscmw_custom_buttons(){
        $settings = get_option('xscmw_setting',true);
        $form_setting = get_option('xscmw_inquiry_form',true);
        if($this->xscmw_valid_users()){
            if(isset($settings['price']) && $settings['price'] == "hide"){
                if(isset($settings['price-pages'])){
                    $this->xscmw_hide_price_function();
                }
            }
            //remove add to cart
            if(isset($settings['enable-cart']) && $settings['enable-cart'] == "hide"){
                if(isset($settings['pages'])){
                    $this->xscmw_hide_cart_function();
                }
            }
            if(isset($form_setting['set-form']) && $form_setting['set-form'] !='hidden_all'){
                if(!isset($form_setting['show-form']) || $form_setting['show-form'] =='woo_tabs'){
                    add_filter( 'woocommerce_product_tabs',array($this,'woo_form_product_tab'));
                }
                if(isset($form_setting['show-form']) && $form_setting['show-form'] == 'woo_area'){
                    if(isset($form_setting['form-position']) && $form_setting['form-position'] =='after_des'){
                        add_action( 'woocommerce_single_product_summary',array($this,'woo_form_product'));
                    }
                    if(isset($form_setting['form-position']) && $form_setting['form-position'] =='after_cart'){
                        add_action( 'woocommerce_after_add_to_cart_button',array($this,'woo_form_product'));
                    }
                    if(isset($form_setting['form-position']) && $form_setting['form-position'] =='after_price'){
                        add_filter( 'woocommerce_get_price_html',array($this,'woo_form_product_after_price'));
                    }
                    
                    
                }
            }

        }
    }
    public function xscmw_valid_users(){
        $settings = get_option('xscmw_setting',true);
        $enable = false;
        $users = isset($settings['users']) ? $settings['users']:'';
        $role = isset($settings['roles']) ? $settings['roles']:'';
        if($users == 'all-users'){
            $enable = true;
        }

        if($users == 'guest-users' && !is_user_logged_in()){
            $enable = true;
        }

        if($users == 'role-user' && is_user_logged_in()){
            $user = $user ? new WP_User( $user ) : wp_get_current_user();
            if($role == $user->roles[0]){
                $enable = true;
            }
        }

        return $enable;
    }

    public function xscmw_hide_cart_function(){
        add_filter( 'woocommerce_loop_add_to_cart_link', array($this,'xscmw_replace_cart_button'), 10, 2 );
        add_action( 'woocommerce_single_product_summary',array($this,'xscmw_replacing_add_to_cart'), 1, 0 );
    }

    public function xscmw_hide_price_function(){
        if(!is_admin()){
            add_filter('woocommerce_get_price_html',array($this, 'xscmw_replacing_price'), 10,2);
        }
    }
    public function xscmw_replacing_add_to_cart() {
        $settings = get_option('xscmw_setting',true);
        switch($settings['pages']){
            case 'all':
                $this->xscmw_hide_cart_button_function();
                break;
            case 'shop':
                if(is_shop()){
                   $this->xscmw_hide_cart_button_function(); 
                }
                break;
            case 'product':
                if(is_singular('product')){
                   $this->xscmw_hide_cart_button_function(); 
                }
                break;
            default:
                break;

        }
    }
    public function xscmw_replacing_price($button,$product) {
        $settings = get_option('xscmw_setting',true);
        switch($settings['price-pages']){
            case 'all':
                $button =$this->xscmw_replace_price_button($button,$product);
                break;
            case 'shop':
                if(is_shop()){
                   $button =$this->xscmw_replace_price_button($button,$product); 
                }
                break;
            case 'product':
                if(is_singular('product')){
                   $button = $this->xscmw_replace_price_button($button,$product); 
                }
                break;
            default:
                break;

        }
        return $button;
    }
    public function xscmw_hide_cart_button_function(){
        global $product;
        $product_id = method_exists( $product, 'get_id' ) ? $product->get_id() : $product->id;
        $settings = get_option('xscmw_setting',true);
            // For variable product types
        $product_data = $this->xscmw_get_product_data($product_id);
        if(!empty($product_data) && $product_data['set_add_cart'] == 'visible'){
            return;
        }else{
            if(isset($settings['products']) && $settings['products'] =='All'){
                if( $product->is_type( 'variable' ) ){
                // Removing add to cart button and quantities
                    remove_action( 'woocommerce_single_variation', 'woocommerce_single_variation_add_to_cart_button', 20 );
                    
                    // The button replacement
                    if(!isset($settings['disable-shop']) && $settings['disable-shop'] !='on'){
                        add_action( 'woocommerce_single_variation', array($this , 'xscmw_custom_button_replacement'), 20 );
                    }
                    
                    
                }else{
                    // Removing add to cart button and quantities
                    remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30 );
                    remove_action('woocommerce_simple_add_to_cart', 'woocommerce_simple_add_to_cart', 30);

                    // The button replacement
                    if(!isset($settings['disable-shop']) || $settings['disable-shop'] !='on'){
                        add_action( 'woocommerce_simple_add_to_cart', array($this , 'xscmw_custom_button_replacement'), 30 );
                        add_action( 'woocommerce_single_product_summary', array($this,'xscmw_custom_button_replacement'), 30 );
                    }
                }
            }else{
                if(!empty($product_data)){
                    if( $product->is_type( 'variable' ) ){
                // Removing add to cart button and quantities
                        remove_action( 'woocommerce_single_variation', 'woocommerce_single_variation_add_to_cart_button', 20 );
                        
                        // The button replacement
                        if(!isset($settings['disable-shop']) || $settings['disable-shop'] !='on'){
                            add_action( 'woocommerce_single_variation', array($this , 'xscmw_custom_button_replacement'), 20 );
                        }
                        
                    }else{
                        // Removing add to cart button and quantities
                        remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30 );
                        remove_action('woocommerce_simple_add_to_cart', 'woocommerce_simple_add_to_cart', 30);

                        // The button replacement
                        if(!isset($settings['disable-shop']) || $settings['disable-shop'] !='on'){
                            add_action( 'woocommerce_simple_add_to_cart', array($this , 'xscmw_custom_button_replacement'), 30 );
                            add_action( 'woocommerce_single_product_summary', array($this,'xscmw_custom_button_replacement'), 30 );
                        }
                    }
                }
            }
        }
        
    }
    public function xscmw_replace_cart_button($button,$product){
        $settings = get_option('xscmw_setting',true);
        $product_page_cart = isset($settings['pdt-replace-add-cart']) ? $settings['pdt-replace-add-cart']:'';
        $shop_page_cart = isset($settings['shop-replace-add-cart']) ? $settings['shop-replace-add-cart']:'';
        $button_add_cart_id = '';
        global $product;
        $product_id = method_exists( $product, 'get_id' ) ? $product->get_id() : $product->id;
        $product_data = $this->xscmw_get_product_data($product_id);
        if(!empty($product_data) && is_array($product_data)){
            if(isset($product_data['addcart_enable']) && $product_data['addcart_enable'] == 'on'){
                $product_page_cart = $product_data['replace-cart-product-page'];
                $shop_page_cart = $product_data['replace-cart-shop-page'];
            }
        }
        if(is_singular('product') && $product_page_cart){
            if( $product_page_cart != 'none'){
                $button_add_cart_id = $product_page_cart;
            }
        }
        if(is_shop() && $shop_page_cart){
            if( $shop_page_cart != 'none'){
                $button_add_cart_id = $shop_page_cart;
            }
        } 
        if(!empty($product_data) && $product_data['set_add_cart'] == 'visible'){
            return $button;
        }else{
            if(isset($settings['products']) && $settings['products'] =='All'){
                $button = $this->xscmw_button_layout($button_add_cart_id);
            }else{
                if(!empty($product_data)){
                  $button = $this->xscmw_button_layout($button_add_cart_id);  
                }
            }
            if(isset($settings['disable-shop']) && $settings['disable-shop'] =='on'){
                $button ='';
            }
            return $button;
        }
        
    }

    public function xscmw_replace_price_button($button,$product){
        $settings = get_option('xscmw_setting',true);
        $product_id = method_exists( $product, 'get_id' ) ? $product->get_id() : $product->id;
        $button_add_cart_id = '';
        $price_cart =isset($settings['price-replace-add-cart']) ? $settings['price-replace-add-cart']:'';
        $product_data = $this->xscmw_get_product_data($product_id);
        if(!empty($product_data) && is_array($product_data)){
            if(isset($product_data['price_enable']) && $product_data['price_enable'] == 'on'){
                $price_cart = $product_data['replace-price'];
            }
        }
        if($price_cart){
            if( $price_cart != 'none'){
                $button_add_cart_id = $price_cart;
            }
        }
        if(!empty($product_data) && $product_data['set_price'] == 'visible'){
            return $button;
        }else{
            $button = $this->xscmw_button_layout($button_add_cart_id);
            return $button;
        }
        
    }
    public  function xscmw_custom_button_replacement(){
        $settings = get_option('xscmw_setting',true);
        $product_page_cart = isset($settings['pdt-replace-add-cart']) ? $settings['pdt-replace-add-cart']:'';
        $shop_page_cart = isset($settings['shop-replace-add-cart']) ? $settings['shop-replace-add-cart']:'';
        $button_add_cart_id = '';
        global $product;
        $product_id = method_exists( $product, 'get_id' ) ? $product->get_id() : $product->id;
        $product_data = $this->xscmw_get_product_data($product_id);
        if(!empty($product_data) && is_array($product_data)){
            if(isset($product_data['addcart_enable']) && $product_data['addcart_enable'] == 'on'){
                $product_page_cart = $product_data['replace-cart-product-page'];
                $shop_page_cart = $product_data['replace-cart-shop-page'];
            }
        }
        if(is_singular('product') && $product_page_cart){
            if( $product_page_cart != 'none'){
                $button_add_cart_id = $product_page_cart;
            }
        }
        if(is_shop() && $shop_page_cart){
            if( $shop_page_cart != 'none'){
                $button_add_cart_id = $shop_page_cart;
            }
        }        
        echo $this->xscmw_button_layout($button_add_cart_id);
        do_action( 'woocommerce_after_add_to_cart_button' );

    }

    public function xscmw_get_product_data($product_id){
        $terms_tags = array();
        $terms_cat = array();
        $terms_tags = get_the_terms($product_id, 'product_tag');
        $data_meta = array();
        if( ! empty( $terms_tags ) && ! is_wp_error( $terms_tags )){
            foreach($terms_tags as $term){
                if(get_term_meta($term->term_id,'xscmw_exclusions',true)){
                    $data_meta = get_term_meta($term->term_id,'xscmw_exclusions',true);
                }
            }
        }
        $terms_cat = get_the_terms($product_id, 'product_cat');
        if(! empty( $terms_cat ) && ! is_wp_error( $terms_cat ) ){
            foreach($terms_cat as $term){
                if(get_term_meta($term->term_id,'xscmw_exclusions',true)){
                    $data_meta = get_term_meta($term->term_id,'xscmw_exclusions',true);
                }
            }
        }
        if(get_post_meta($product_id,'xscmw_exclusions',true)){
            $data_meta = get_post_meta($product_id,'xscmw_exclusions',true);
        }
        if(!empty($data_meta) && is_array($data_meta)){
            return $data_meta;
        }else{
            return array();
        }
    }

    public function xscmw_button_layout($button_add_cart_id){
        $icon_font = '';
        $title = ''; 
        $css = '';
        global $product;
        $product_id = method_exists( $product, 'get_id' ) ? $product->get_id() : $product->id;
        $button = '';
        if($button_add_cart_id){
            $button_detail = get_post_meta($button_add_cart_id,'xscmw_button_form',true);
            if(isset($button_detail['choose-icon']) && !empty($button_detail['choose-icon'])){
                $icon_fonts = explode(':',$button_detail['choose-icon']);
                if($icon_fonts[0] == 'Dashicons'){
                    $icon_font = 'dashicons dashicons-'.$icon_fonts[1];
                }else{
                    $icon_font = 'fa fa-'.$icon_fonts[1];
                }
            }
            $title = isset($button_detail['xscmw-label-text'])?$button_detail['xscmw-label-text']:'';
            $css = '.xscmw-custom-button-'.$button_add_cart_id.'{ border-style:solid;';
            $css .='color:'.$button_detail['text-color-default'].';';
            $css .='background-color:'.$button_detail['background-color-default'].';';
            $css .='border-color:'.$button_detail['broder-color-default'].';';
            $css .='border-width:'.$button_detail['broder-thickness'].'px;';
            $css .='border-radius:'.$button_detail['broder-radius'].'px;';
            $css .='margin:'.$button_detail['margin-top'].'px '.$button_detail['margin-right'].'px '.$button_detail['margin-bottom'].'px '.$button_detail['margin-left'].'px ;';
            $css .='padding:'.$button_detail['padding-top'].'px '.$button_detail['padding-right'].'px '.$button_detail['padding-bottom'].'px '.$button_detail['padding-left'].'px;';
            $width_type = ($button_detail['width-type'] == 'percent' )?'%': 'px';
            $css .='width:'.$button_detail['width-number'].$width_type .';' ;
            $css .= '}';
            $css .= ' .xscmw-custom-button-'.$button_add_cart_id.':hover{';
            $css .='color:'.$button_detail['text-color-hover'].';';
            $css .='background-color:'.$button_detail['background-color-hover'].';';
            $css .='border-color:'.$button_detail['broder-color-hover'].';';
            $css .= '}';
            $css .=' .xscmw-form-icon-'.$button_add_cart_id.'{';
            $css .='color:'.$button_detail['icon-color-default'].';';
            $css .='font-size:'.$button_detail['icon-size'].'px;';
            $css .='align-self:'.$button_detail['icon-align'].';';
            $css .='}';
            $css .= '.xscmw-form-icon-'.$button_add_cart_id.':hover{';
            $css .= 'color:'.$button_detail['icon-color-hover'].';';
            $css .= '}';
            if($button_detail['link-to'] == 'product'){
                $button .= "<a href='".get_permalink($product_id)."'>";
            }
            if($button_detail['link-to'] == 'custom'){
                $button .= "<a href='".$button_detail['custom-url']."'>";
            }
        }
       
        
        
        $button .= '<div class="xscmw-custom-button-container">
                <span class="xscmw-custom-button-'.$button_add_cart_id.'">
                    <span class="xscmw-form-icon-'.$button_add_cart_id.' '.$icon_font.'"></span>
                    <span class="xscmw-form-title">'.$title.'</span>
                </span>
            </div>';
        if($button_add_cart_id){
            if($button_detail['link-to'] == 'product' || $button_detail['link-to'] == 'custom'){
                $button .= "</a>";
            }
        }
        wp_register_style( 'xscmw_button_style', false );
        wp_enqueue_style( 'xscmw_button_style' );
        wp_add_inline_style( 'xscmw_button_style', $css );
        return $button;
    }

    public function woo_form_product_tab($tabs){
        $form_setting = get_option('xscmw_inquiry_form',true);
        global $product;
        $enable = false;
        if(isset($form_setting['set-form']) && $form_setting['set-form'] =='visible_all'){
            $enable = true;
        }else{
            $product_id = method_exists( $product, 'get_id' ) ? $product->get_id() : $product->id;
            $product_data = $this->xscmw_get_product_data($product_id);
            if(!empty($product_data) && is_array($product_data)){
                if(isset($product_data['inquiry_form']) && $product_data['inquiry_form'] =='on'){
                    $enable = true;
                }
            }
        }
        if($enable){
            $tabs['inquiry_form'] = array(
                'title'     => __( 'Inquiry Form', 'woocommerce' ),
                'priority'  => 50,
                'callback'  => array($this,'woo_form_product_tab_content')
            );
        }
        return $tabs;
    }

    public function woo_form_product(){
        $form_setting = get_option('xscmw_inquiry_form',true);
        global $product;
        $enable = false;
        if(isset($form_setting['set-form']) && $form_setting['set-form'] =='visible_all'){
            $enable = true;
        }else{
            $product_id = method_exists( $product, 'get_id' ) ? $product->get_id() : $product->id;
            $product_data = $this->xscmw_get_product_data($product_id);
            if(!empty($product_data) && is_array($product_data)){
                if(isset($product_data['inquiry_form']) && $product_data['inquiry_form'] =='on'){
                    $enable = true;
                }
            }
        }
        if($enable){
            $this->woo_form_product_tab_content();
        }
    }

    public function woo_form_product_after_price($price){
        $form_setting = get_option('xscmw_inquiry_form',true);
        global $product;
        $enable = false;
        if(isset($form_setting['set-form']) && $form_setting['set-form'] =='visible_all'){
            $enable = true;
        }else{
            $product_id = method_exists( $product, 'get_id' ) ? $product->get_id() : $product->id;
            $product_data = $this->xscmw_get_product_data($product_id);
            if(!empty($product_data) && is_array($product_data)){
                if(isset($product_data['inquiry_form']) && $product_data['inquiry_form'] =='on'){
                    $enable = true;
                }
            }
        }
        if($enable && is_singular('product')){
            return $price.$this->woo_form_product_price_content();
        }
    }

    public function woo_form_product_tab_content(){
        $form_setting = get_option('xscmw_inquiry_form',true);
        $title = isset($form_setting['tab-title']) ? $form_setting['tab-title']: '';
        $sub_title = isset($form_setting['text-before-form']) ? $form_setting['text-before-form']: '';
        if(isset($form_setting['form-style']) && $form_setting['form-style'] =='toggle' ){
            if($form_setting['show-form'] == 'woo_area'){
                echo '<div class="xscmw-form-wrapper"><div class="group-title">';
            }
            
        }
        echo '<h2>'.$title.'</h2>';
        if(isset($form_setting['form-style']) && $form_setting['form-style'] =='toggle' ){
            if($form_setting['show-form'] == 'woo_area'){
                echo '</div><div class="xscmw-form">';
            }
            
        }
        echo '<p>'.$sub_title.'</p>';
        $id = $form_setting['choose_form'];
        if(isset($form_setting['form_plugin']) && $form_setting['form_plugin'] =='contct_form_7'){
            echo do_shortcode('[contact-form-7 id="'.$id.'"]');
        }
        if(isset($form_setting['form_plugin']) && $form_setting['form_plugin'] =='ninja_forms'){
            echo do_shortcode('[ninja_forms id="'.$id.'"]');
        }
        if(isset($form_setting['form-style']) && $form_setting['form-style'] =='toggle' ){
            if($form_setting['show-form'] == 'woo_area'){
                echo '</div></div>';
            }
            
        }
    }

    public function woo_form_product_price_content(){
        $form_setting = get_option('xscmw_inquiry_form',true);
        $content = '';
        if(isset($form_setting['form-style']) && $form_setting['form-style'] =='toggle' ){
            $content .='<div class="xscmw-form-wrapper"><div class="group-title">';
        }
        $title = isset($form_setting['tab-title']) ? $form_setting['tab-title']: '';
        $sub_title = isset($form_setting['text-before-form']) ? $form_setting['text-before-form']: '';
        $content .= '<h2>'.$title.'</h2>';
        if(isset($form_setting['form-style']) && $form_setting['form-style'] =='toggle' ){
            $content .='</div><div class="xscmw-form">';
        }
        $content .='<p>'.$sub_title.'</p>';
        $id = $form_setting['choose_form'];
        if(isset($form_setting['form_plugin']) && $form_setting['form_plugin'] =='contct_form_7'){
            $content .= do_shortcode('[contact-form-7 id="'.$id.'"]');
        }
        if(isset($form_setting['form_plugin']) && $form_setting['form_plugin'] =='ninja_forms'){
            $content .= do_shortcode('[ninja_forms id="'.$id.'"]');
        }
        if(isset($form_setting['form-style']) && $form_setting['form-style'] =='toggle' ){
            $content .='</div></div>';
        }
        return $content;
    }
}
