<?php
if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}
add_action('wp_loaded', 'cwsa_customer_management_handler');
function cwsa_customer_management_handler() {
	if (!isset($_GET['cwsa_register_management_nonce']) || !wp_verify_nonce($_GET['cwsa_register_management_nonce'], 'cwsa_register_management_action')) {
		return;
	}

	if (!isset($_GET['page'])
		|| !($_GET['page'] === 'cwsa-settings')
		|| !($_GET['tab'] === 'register-management')) {
		return;
	}

	$redirect_url = remove_query_arg(
		array('_wp_http_referer', 'cwsa_register_management_nonce', 'sites', 'bulk_actions'),
		wp_unslash($_SERVER['REQUEST_URI'])
	);

	if (isset($_GET['bulk_actions'])) {
		$action = sanitize_text_field($_GET['action']);

		if (isset($_GET['sites'])) {
			$sites = array_map('sanitize_text_field', $_GET['sites']);

			$count = 0;

			switch ($action) {
				case 'cancel':
					foreach ($sites as $site_id) {
						if (CWSA()->db()->cancel_request($site_id)) {
							$count++;
						}
					}
					if ($count === 0) {
						cwsa_admin_message_add(esc_html__('Can not cancel request!', 'cwsa'), 'error');
					} else {
						cwsa_admin_message_add(esc_html__('Cancelled request success!', 'cwsa'), 'success');
					}
					break;
				case 'resend':
					foreach ($sites as $site_id) {
						if (cwsa_resend_email($site_id)) {
							$count++;
						}
					}

					if ($count === 0) {
						cwsa_admin_message_add(esc_html__('Can not resend email!', 'cwsa'), 'error');
					} else {
						cwsa_admin_message_add(esc_html__('Resend email success!', 'cwsa'), 'success');
					}

					break;
				case 'drop':
					foreach ($sites as $site_id) {
						if (cwsa_drop_sandbox($site_id)) {
							$count++;
						}
					}
					if ($count === 0) {
						cwsa_admin_message_add(esc_html__('Can not drop sandbox site!', 'cwsa'), 'error');
					} else {
						cwsa_admin_message_add(esc_html__('Drop sandbox site success!', 'cwsa'), 'success');
					}
					break;
			}
		}
	}
	else {
		if (isset($_GET['action'])) {
			$action = $_GET['action'];
			$site_id = $_GET['site_id'];
			switch ($action) {
				case 'cancel':
					if (!CWSA()->db()->cancel_request($site_id)) {
						cwsa_admin_message_add(esc_html__('Can not cancel request!', 'cwsa'), 'error');
					} else {
						cwsa_admin_message_add(esc_html__('Cancelled request success!', 'cwsa'), 'success');
					}
					break;

				case 'resend':
					if (!cwsa_resend_email($site_id)) {
						cwsa_admin_message_add(esc_html__('Can not resend email!', 'cwsa'), 'error');
					} else {
						cwsa_admin_message_add(esc_html__('Resend email success!', 'cwsa'), 'success');
					}
					break;

				case 'drop':
					if (!cwsa_drop_sandbox($site_id)) {
						cwsa_admin_message_add(esc_html__('Can not drop sandbox site!', 'cwsa'), 'error');
					} else {
						cwsa_admin_message_add(esc_html__('Drop sandbox site success!', 'cwsa'), 'success');
					}
					break;
			}
			$redirect_url = remove_query_arg(array('action', 'site_id'), $redirect_url);
		}
	}

	wp_redirect($redirect_url);
	exit;
}

function cwsa_resend_email($site_id) {
	$site = CWSA()->db()->get_site_by_id($site_id);

	if ($site === false) {
		return false;
	}
	$info = cwsa_get_site_status($site);

	if ($info['status'] !== 'pending') {
		return false;
	}

	CWSA()->email()->request_create_sandbox(array(
		'user_email' => $site->email,
		'authen_link' => home_url('/') . '?cwsa_authen_key=' . $site->authen_key
	));
	return true;
}

function cwsa_drop_sandbox($site_id) {
	$site = CWSA()->db()->get_site_by_id($site_id);
	if ($site === null) {
		return false;
	}
	$info = cwsa_get_site_status($site);
	if ($info['status'] !== 'running') {
		return false;
	}

	return cwsa_delete_sandbox_site($site);
}