<?php
if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

function cwsa_get_setting_tabs() {
	return apply_filters('cwsa_setting_tabs', array(
		'general'     => array(
			'label' => esc_html__( 'General', 'cwsa' ),
			'link'  => admin_url( 'admin.php?page=cwsa-settings&tab=general')
		),
		'email' => array(
			'label' => esc_html__( 'Email', 'cwsa' ),
			'link'  => admin_url( 'admin.php?page=cwsa-settings&tab=email')
		),
		'register-management' => array(
			'label' => esc_html__( 'Register Management', 'cwsa' ),
			'link'  => admin_url( 'admin.php?page=cwsa-settings&tab=register-management')
		),
	));
}

function cwsa_get_captcha_list() {
	return apply_filters('', array(
		'' => esc_html__('--[Select captcha type]--','cwsa'),
		'math_captcha' => esc_html__('Math Captcha','cwsa'),
	));
}

add_action('wp_loaded', 'cwsa_save_settings');
function cwsa_save_settings() {
	if (!isset($_POST['tab'])) {
		return;
	}
	$tab = sanitize_text_field($_POST['tab']);
	if (!isset($_POST["cwsa_save_setting_{$tab}_nonce"])
	    || !wp_verify_nonce($_POST["cwsa_save_setting_{$tab}_nonce"], "cwsa_save_setting_{$tab}_action")) {
		return;
	}

	$tab = sanitize_text_field($_POST['tab']);

	do_action("cwsa_save_settings_{$tab}", $tab);
}

add_action('cwsa_save_settings_general', 'cwsa_save_settings_general');
function cwsa_save_settings_general($tab) {
	$site_default = sanitize_text_field($_POST['site_default']);
	$time_to_delete = sanitize_text_field($_POST['time_to_delete']);
	$sandbox_site_prefix = sanitize_text_field($_POST['sandbox_site_prefix']);
	$limit_sandbox_site = sanitize_text_field($_POST['limit_sandbox_site']);
	$sandbox_user_role = sanitize_text_field($_POST['sandbox_user_role']);
	$auto_assign_supper_admin = isset($_POST['auto_assign_supper_admin'])
		? sanitize_text_field($_POST['auto_assign_supper_admin'])
		: '';
	$request_sandbox_page = sanitize_text_field($_POST['request_sandbox_page']);
	$captcha_type = sanitize_text_field($_POST['captcha_type']);

	CWSA()->options()->set_value('site_default', $site_default);
	CWSA()->options()->set_value('time_to_delete', $time_to_delete);
	CWSA()->options()->set_value('sandbox_site_prefix', $sandbox_site_prefix);
	CWSA()->options()->set_value('limit_sandbox_site', $limit_sandbox_site);
	CWSA()->options()->set_value('sandbox_user_role', $sandbox_user_role);
	CWSA()->options()->set_value('auto_assign_supper_admin', $auto_assign_supper_admin);
	CWSA()->options()->set_value('request_sandbox_page', $request_sandbox_page);
	CWSA()->options()->set_value('captcha_type', $captcha_type);

	CWSA()->options()->update();

	cwsa_admin_message_add(esc_html__('Save settings done!','cwsa'), 'success');
}

add_action('cwsa_save_settings_email', 'cwsa_save_settings_email');
function cwsa_save_settings_email($tab) {
	$section = isset($_POST['section']) ? sanitize_text_field($_POST['section']) : '';
	if ($section === '') {
		$email_from_name = sanitize_text_field($_POST['email_from_name']);
		$email_from_address = sanitize_text_field($_POST['email_from_address']);
		$email_footer_text = sanitize_text_field($_POST['email_footer_text']);

		CWSA()->options()->set_value('email_from_name', $email_from_name);
		CWSA()->options()->set_value('email_from_address', $email_from_address);
		CWSA()->options()->set_value('email_footer_text', $email_footer_text);

		CWSA()->options()->update();

		cwsa_admin_message_add(esc_html__('Save email settings done!','cwsa'), 'success');
	}
	else {
		if (has_action("cwsa_save_settings_email_{$section}")) {
			do_action("cwsa_save_settings_email_{$section}", $section);
		}
		else {
			$email_info = array_map('sanitize_text_field', $_POST['email']);

			$email_list = CWSA()->options()->get_emails();
			$email_list[$section] = $email_info;

			CWSA()->options()->set_value('emails', $email_list);

			CWSA()->options()->update();

			cwsa_admin_message_add(esc_html__('Save email template done!','cwsa'), 'success');
		}
	}
}