<?php
if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}
if (!class_exists('CWSA_Clone')) {
	class CWSA_Clone
	{
		private static $_instance;
		public static function getInstance()
		{
			if (self::$_instance == null) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}

		public function init() {
			add_action('cwsa_create_sandbox_site_done', array($this, 'clone_data_after_create_sandbox'), 10, 2);
		}

		function clone_data_after_create_sandbox($blog_id, $user_id) {
			/**
			 * Clone data when $site_default is set
			 */
			$site_default = CWSA()->options()->get_site_default();
			if (($site_default !== '')) {
				$site_details = get_blog_details($site_default);
				if ($site_details !== false) {
					$source_blog_id = CWSA()->options()->get_site_default();
					$target_blog_id = $blog_id;

					$this->clone_upload_files($source_blog_id, $target_blog_id);
					$this->clone_database($source_blog_id, $target_blog_id);
					$this->replace_database($source_blog_id, $target_blog_id, $user_id);
				}
			}
			$this->change_user_role($blog_id, $user_id);
		}

		public function clone_upload_files($source_blog_id, $target_blog_id) {
			$source_dir = $this->get_upload_dir($source_blog_id);
			$target_dir = $this->get_upload_dir($target_blog_id);
			$ms_dir = ($source_blog_id == 1) ? "{$source_dir}/sites" : '';

			$this->copy_directory_files($source_dir, $target_dir, $ms_dir);
		}

		/**
		 * Get global tables no copy
		 *
		 * @return array
		 */
		public function get_no_copy_tables() {
			global $wpdb;

			/**
			 * Global tables
			 */
			$_no_copy_tables = array(
				"{$wpdb->base_prefix}blogs",
				"{$wpdb->base_prefix}blogmeta",
				"{$wpdb->base_prefix}registration_log",
				"{$wpdb->base_prefix}signups",
				"{$wpdb->base_prefix}site",
				"{$wpdb->base_prefix}sitemeta",
				"{$wpdb->base_prefix}usermeta",
				"{$wpdb->base_prefix}users",
				"{$wpdb->base_prefix}cwsa_site",
			);

			return $_no_copy_tables;
		}

		public function clone_database($source_blog_id, $target_blog_id) {
			global $wpdb;
			$source_table_prefix = $wpdb->get_blog_prefix( $source_blog_id );
			$target_table_prefix = $wpdb->get_blog_prefix( $target_blog_id );

			$_copy_tables = array();

			if ($source_table_prefix == $wpdb->base_prefix) {

				$_no_copy_tables_pattern = "/^(" . implode( '|', $this->get_no_copy_tables()) . ")$/";

				$_tables = $wpdb->get_results( 'SHOW TABLES', ARRAY_N );

				foreach ($_tables as $table_name) {

					$is_main_table = preg_match( $_no_copy_tables_pattern, $table_name[0] );
					$is_no_copy_table = preg_match( "/{$wpdb->base_prefix}(?!\d+_)/", $table_name[0] );

					if (!$is_main_table && $is_no_copy_table) {
						array_push($_copy_tables, $table_name[0]);
					}
				}
			}
			else {
				$like_source_table_prefix = str_replace( '_', '\_', $source_table_prefix );
				$_tables = $wpdb->get_results( "SHOW TABLES LIKE '{$like_source_table_prefix}%'", ARRAY_N );
				foreach ($_tables as $table_name) {
					array_push($_copy_tables, $table_name[0]);
				}
			}

			if (!empty($_copy_tables)) {
				foreach ($_copy_tables as $table_name) {
					$_source_table = $table_name;
					$_target_table = str_replace( $source_table_prefix, $target_table_prefix, $_source_table );
					$this->copy_table($_source_table, $_target_table, $source_table_prefix, $target_table_prefix);
				}
			}

			// Change site title
			$blogname = get_blog_option($target_blog_id, 'blogname');
			update_blog_option($target_blog_id, 'blogname', "{$blogname} - {$target_blog_id}");
		}

		public function copy_table($source_table, $target_table, $source_table_prefix, $target_table_prefix) {
			global $wpdb;

			// Drop table if $target site table exists
			$wpdb->query( "DROP TABLE IF EXISTS {$target_table}");

			// Create table base on $source table
			$wpdb->query( "CREATE TABLE {$target_table} LIKE {$source_table}");

			// Copy content
			if ( $source_table === $source_table_prefix . 'options') {
				$wpdb->query( $wpdb->prepare( "INSERT {$target_table} SELECT * FROM {$source_table} WHERE option_name NOT RLIKE %s AND option_name NOT RLIKE %s", "^_transient_feed_", "^_transient_rss_" ) );
			} elseif ( $source_table === $source_table_prefix . 'posts') {
				$wpdb->query( $wpdb->prepare( "INSERT {$target_table} SELECT * FROM {$source_table} WHERE post_type != %s", 'revision' ) );
			} elseif ( $source_table === $source_table_prefix . '_postmeta') {
				$wpdb->query( $wpdb->prepare( "INSERT {$target_table} SELECT * FROM {$source_table} WHERE meta_key != %s AND meta_key != %s", '_edit_lock', '_edit_last' ) );
			} else {
				$wpdb->query( "INSERT {$target_table} SELECT * FROM {$source_table}" );
			}
		}

		public function replace_database($source_blog_id, $target_blog_id, $user_id) {
			global $wpdb;

			$source_table_prefix = $wpdb->get_blog_prefix( $source_blog_id );
			$target_table_prefix = $wpdb->get_blog_prefix( $target_blog_id );

			$source_blog_detail = get_blog_details( $source_blog_id );
			$target_blog_detail = get_blog_details( $target_blog_id );

			if (($source_blog_detail === false) || ($target_blog_detail === false)) {
				return;
			}

			$replace_array = array();

			if (is_subdomain_install()) {
				$source_sub_domain = $source_blog_detail->domain;
				$target_sub_domain = $target_blog_detail->domain;

			} else {
				$source_sub_domain = untrailingslashit( $source_blog_detail->domain . $source_blog_detail->path );
				$target_sub_domain = $target_blog_detail->domain . $target_blog_detail->path;
			}

			$replace_array[ $source_sub_domain ] = $target_sub_domain;
			$replace_array[ urlencode($source_sub_domain) ] = urlencode($target_sub_domain);
			$replace_array[ str_replace('/', '\\/', $source_sub_domain) ] = str_replace('/', '\\/', $target_sub_domain);

			// Reset the option_name: _user_roles row in the _options table back to the id of the target blog
			$replace_array[ $source_table_prefix . 'user_roles' ] = $target_table_prefix . 'user_roles';

			if ( $source_blog_id == 1 ) {
				switch_to_blog( $source_blog_id );

				$source_uploads_info = wp_upload_dir();
				restore_current_blog();

				$source_uploads_dir     = str_replace( get_site_url( $source_blog_id ), '', $source_uploads_info['baseurl'] );
				$target_uploads_dir = '/wp-content/uploads/sites/' . $target_blog_id;

				$replace_array[ $source_uploads_dir ] = $target_uploads_dir;
				$replace_array[ urlencode($source_uploads_dir) ] = urlencode($target_uploads_dir);
				$replace_array[ urlencode(urlencode($source_uploads_dir)) ] = urlencode(urlencode($target_uploads_dir));
				$replace_array[ str_replace('/', '\\/', $source_uploads_dir) ] = str_replace('/', '\\/', $target_uploads_dir);
			}
			else {
				$source_blog_site_str = '/sites/' . $source_blog_id . '/';
				$target_blog_site_str = '/sites/' . $target_blog_id . '/';

				$replace_array[ $source_blog_site_str ] = $target_blog_site_str;
				$replace_array[ urlencode($source_blog_site_str) ] = urlencode($target_blog_site_str);
				$replace_array[ urlencode(urlencode($source_blog_site_str)) ] = urlencode(urlencode($target_blog_site_str));
				$replace_array[ str_replace('/', '\\/', $source_blog_site_str) ] = str_replace('/', '\\/', $target_blog_site_str);
			}

			$list_tables = $wpdb->get_results( $wpdb->prepare( "SHOW TABLES LIKE %s", $target_table_prefix . '%' ), ARRAY_N );

			// Replace url in database
			foreach ($list_tables as $tbl) {
				$table_name = $tbl[0];

				$test_row     = $wpdb->get_row( "SELECT * FROM " . $table_name . " LIMIT 1", ARRAY_N );
				$list_column_name = $wpdb->get_col_info( 'name', - 1 );

				// Search for fields we can replace
				$where = '';
				foreach ( $replace_array as $old_value => $new_value ) {
					foreach ( $list_column_name as $column_name ) {
						$where .= empty( $where ) ? '' : ' OR ';
						$where .= $wpdb->prepare( $column_name . ' like %s ', '%' . $old_value . '%' );
					}
				}

				$replace_rows = $wpdb->get_results( "SELECT * FROM {$table_name} WHERE " . $where, ARRAY_A );

				if ( ! count( $replace_rows ) ) {
					continue;
				}

				foreach ( $replace_rows as $row ) {
					$query = 'UPDATE ' . $table_name;

					$set   = '';

					$is_execute_query = false;

					foreach ( $row as $col_name => $col_content ) {
						if ( ! is_string( $col_content ) ) {
							continue;
						}

						$edited_value = $col_content;
						if ( is_serialized( $col_content ) ) {
							$unserialized = unserialize( $edited_value );
							foreach ( $replace_array as $old_value => $new_value ) {
								$this->recursive_replace_data( $old_value, $new_value, $unserialized );
							}
							$edited_value = serialize( $unserialized );
						} else {
							foreach ( $replace_array as $old_value => $new_value ) {
								if ( stripos( $edited_value, $new_value ) === false ) {
									$edited_value = str_replace( $old_value, $new_value, $edited_value );
								}
							}
						}

						if ( $edited_value != $col_content ) {
							$set .= empty( $set ) ? '' : ', ';
							$set .= $wpdb->prepare( $col_name . ' = %s ', $edited_value );
							$is_execute_query = true;
						}
					}
					$query .= ' SET ' . $set;

					// Form where keys based on the primary keys ('ID' or '*_ID')
					$where_keys = '';
					foreach ( $row as $col_name => $col_content ) {
						if ( strtolower( $col_name ) != 'id' || stripos( strtolower( $col_name ), '_id' ) === false ) {
							continue;
						}
						$where_keys .= empty( $where_keys ) ? '' : ' AND ';
						$where_keys .= $wpdb->prepare( $col_name . ' = %s ', $col_content );
					}
					// If no where clause yet, use everything
					if ( empty( $where_keys ) ) {
						foreach ( $row as $col_name => $col_content ) {
							$where_keys .= empty( $where_keys ) ? '' : ' AND ';
							$where_keys .= $wpdb->prepare( $col_name . ' = %s ', $col_content );
						}
					}
					$query .= ' WHERE ' . $where_keys;

					if ( $is_execute_query ) {
						$wpdb->query( $query );
					}
				}
			}

			// Replace post author
			$wpdb->query( $wpdb->prepare( "UPDATE {$target_table_prefix}posts SET post_author = %d", $user_id ) );
		}

		public function change_user_role($target_blog_id, $user_id) {
			$target_blog_detail = get_blog_details( $target_blog_id );

			if (($target_blog_detail === false)) {
				return;
			}

			$users = get_users( array( 'blog_id' => $target_blog_id ) );
			$user_role = CWSA()->options()->get_sandbox_user_role();


			switch_to_blog($target_blog_id);
			foreach ( $users as $user ) {
				if ( ($user->ID == $user_id) && ($user_role == 'administrator') ) {
					continue;
				}
				remove_user_from_blog($user->ID);
			}

			if( $user_role != 'administrator' ){
				add_user_to_blog( $target_blog_id, $user_id, $user_role );
			}

			if (CWSA()->options()->get_auto_assign_supper_admin() === 'on') {
				$supper_admins = get_super_admins();
				foreach ($supper_admins as $un) {
					$user = get_user_by('login', $un);
					if ($user) {
						add_user_to_blog($target_blog_id, $user->ID, 'administrator');
					}
				}
			}

			restore_current_blog();
		}

		public function recursive_replace_data($find, $replace, &$data ) {
			if ( is_array( $data ) ) {
				foreach ( $data as $key => $value ) {
					$this->recursive_replace_data( $find, $replace, $data[ $key ] );
				}
			}
			else if (is_object($data)) {
				foreach ( $data as $key => $value ) {
					$this->recursive_replace_data( $find, $replace, $data->{$key} );
				}
			}
			else if (is_string($data)){
				if ( stripos( $data, $replace ) === false ) {
					$data = str_replace( $find, $replace, $data );
				}
			}
		}

		public function copy_directory_files($source_dir, $target_dir, $ms_dir = '') {

			$copy_mount = 0;
			if ( is_dir( $source_dir ) ) {
				if ( ! file_exists( $target_dir ) ) {
					mkdir( $target_dir );
				}

				$list_files = scandir( $source_dir );
				foreach ( $list_files as $file ) {
					if (($file === '.') || ($file === '..') || ("{$source_dir}/{$file}" === $ms_dir)) {
						continue;
					}

					$copy_mount += $this->copy_directory_files("{$source_dir}/{$file}", "{$target_dir}/{$file}");
				}
			}
			else {
				if (file_exists($source_dir)) {
					copy($source_dir, $target_dir);
					$copy_mount++;
				}
			}

			return $copy_mount;
		}

		/**
		 * Get upload directory by blog_id
		 *
		 * @param $blog_id
		 *
		 * @return mixed|string
		 */
		public function get_upload_dir($blog_id) {
			if (CWSA()->cache()->is_exists('blog_dir_' . $blog_id)) {
				return CWSA()->cache()->get_value('blog_dir_' . $blog_id);
			}

			$_upload_dir_path = cwsa_get_upload_dir($blog_id);

			CWSA()->cache()->set_value('blog_dir_' . $blog_id, $_upload_dir_path);

			return $_upload_dir_path;
		}
	}
}