<?php
if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

if (!class_exists('CreateWordPressSandboxAutomatic')) {
	final class CreateWordPressSandboxAutomatic {
		/*
			 * loader instances
			 */
		private static $_instance = NULL;

		public static function get_instance()
		{
			if (self::$_instance === NULL) {
				self::$_instance = new self();
			}

			return self::$_instance;
		}

		public $page_size = 20;


		public function __construct() { }


		/**
		 * Init plugin
		 */
		public function init() {
			$this->includes();

			cwsa_session_start();

			CWSA_Install::getInstance()->init();
			CWSA_Assets::get_instance()->init();

			$current_blog_id = get_current_blog_id();
			if (($current_blog_id == 1) || (CWSA()->db()->get_site_by_blog_id($current_blog_id) === null)) {
				CWSA_Admin::get_instance()->init();
				CWSA_Email::get_instance()->init();
				CWSA_Clone::getInstance()->init();
				CWSA_Math_Captcha::get_instance()->init();
			}
			else {
				CWSA_Sandbox_Timer::getInstance()->init();
			}
			do_action( 'cwsa_init' );
		}

		/**
		 * Include functions for plugin
		 */
		public function includes() {
			/**
			 * Load plugin functions
			 */
			$this->load_file('inc/functions/autoload.php');
			$this->load_file('inc/functions/core.php');
			$this->load_file('inc/functions/multisite.php');
			$this->load_file('inc/functions/handler.php');
			$this->load_file('inc/functions/shortcodes.php');
			$this->load_file('inc/functions/cron-job.php');
			$this->load_file('inc/functions/templates.php');

		}

		public function get_option_name() {
			return apply_filters('cwsa_option_name', 'cwsa');
		}

		public function get_meta_prefix() {
			return 'cwsa_';
		}

		public function get_assets_handler() {
			return 'cwsa-';
		}

		public function template_path() {
			return apply_filters('cwsa_template_path', 'cwsa/');
		}

		public function plugin_dir($file = '') {
			return plugin_dir_path(CWSA_PLUGIN_FILE ) . $file;
		}

		public function plugin_file() {
			return plugin_basename(CWSA_PLUGIN_FILE);
		}

		public function plugin_url($file = '') {
			return trailingslashit( plugins_url( '/', CWSA_PLUGIN_FILE ) ) . $file;
		}

		public function plugin_data() {
			if (!function_exists('get_plugin_data')) {
				require_once(ABSPATH . 'wp-admin/includes/plugin.php');
			}
			return get_plugin_data( CWSA_PLUGIN_FILE );
		}

		public function plugin_version() {
			$plugin_data = $this->plugin_data();
			return $plugin_data['Version'];
		}

		/**
		 * Load plugin file
		 *
		 * @param $file_path
		 */
		public function load_file($file_path) {
			include_once (CWSA_ABSPATH . $file_path);
		}

		/**
		 * @return CWSA_Options
		 */
		public function options() {
			return CWSA_Options::get_instance();
		}

		/**
		 * @return CWSA_Email
		 */
		public function email() {
			return CWSA_Email::get_instance();
		}

		/**
		 * @return CWSA_Database
		 */
		public function db() {
			return CWSA_Database::getInstance();
		}

		/**
		 * @return CWSA_Cache
		 */
		public function cache() {
			return CWSA_Cache::getInstance();
		}

		/**
		 * @return CWSA_Message
		 */
		public function messages() {
			return CWSA_Message::get_instance();
		}
	}
}