<?php
if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}
if (!class_exists('CWSA_Database')) {
	class CWSA_Database
	{
		private static $_instance;
		public static function getInstance()
		{
			if (self::$_instance == null) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}

		/**
		 * @return string
		 */
		public function get_table_name() {
			global $wpdb;

			return "{$wpdb->base_prefix}cwsa_site";
		}

		public function get_site_by_id($id) {
			global $wpdb;
			$r = $wpdb->get_row( $wpdb->prepare("SELECT * FROM {$this->get_table_name()} WHERE ID=%d", $id));
			return $r;
		}

		public function get_site_by_authen_key($authen_key) {
			global $wpdb;
			return $wpdb->get_row( $wpdb->prepare("SELECT * FROM {$this->get_table_name()} WHERE authen_key=%s", $authen_key));
		}

		public function check_site_active_by_email($user_email) {
			global $wpdb;
			return $wpdb->get_row( $wpdb->prepare("SELECT ID FROM {$this->get_table_name()} WHERE email=%s AND created_date IS NOT NULL AND close_date IS NULL", $user_email)) !== null;
		}

		public function get_site_by_blog_id($blog_id) {
			global $wpdb;
			$r = $wpdb->get_row( $wpdb->prepare("SELECT * FROM {$this->get_table_name()} WHERE blog_id=%d", $blog_id));
			return $r;
		}

		public function is_sandbox_site($blog_id) {
			global $wpdb;
			return $wpdb->get_row( $wpdb->prepare("SELECT ID FROM {$this->get_table_name()} WHERE blog_id=%d", $blog_id)) !== null;
		}

		public function insert($data) {
			global $wpdb;
			return $wpdb->insert( $this->get_table_name(), $data);
		}

		public function update($id, $data) {
			global $wpdb;
			return $wpdb->update($this->get_table_name(), $data, array(
				'ID' => $id
			));
		}

		public function delete($id) {
			global $wpdb;
			return $wpdb->delete($this->get_table_name(), array(
				'ID' => $id
			));
		}

		public function get_all_site_amount() {
			global $wpdb;
			$count = $wpdb->get_var("SELECT COUNT(*) FROM {$this->get_table_name()}");
			return $count;
		}

		public function get_active_site_amount() {
			global $wpdb;
			$count = $wpdb->get_var("SELECT COUNT(*) FROM {$this->get_table_name()} WHERE created_date IS NOT NULL AND close_date IS NULL");
			return $count;
		}

		public function get_pending_site_amount() {
			global $wpdb;
			$count = $wpdb->get_var("SELECT COUNT(*) FROM {$this->get_table_name()} WHERE created_date IS NULL AND close_date IS NULL");
			return $count;
		}

		public function get_cancel_site_amount() {
			global $wpdb;
			$count = $wpdb->get_var("SELECT COUNT(*) FROM {$this->get_table_name()} WHERE created_date IS NULL AND close_date IS NOT NULL");
			return $count;
		}

		public function get_closed_site_amount() {
			global $wpdb;
			$count = $wpdb->get_var("SELECT COUNT(*) FROM {$this->get_table_name()} WHERE created_date IS NOT NULL AND close_date IS NOT NULL");
			return $count;
		}

		public function get_request_months() {
			global $wpdb;
			$months = $wpdb->get_results("SELECT year(request_date) as request_year, month(request_date) as request_month FROM {$this->get_table_name()} GROUP BY year(request_date), month(request_date)");
			$result = array();
			foreach ($months as $m) {
				$dateObj   = DateTime::createFromFormat('!m', $m->request_month);
				$monthName = $dateObj->format('F');
				$result[] = array(
					'value' => "{$m->request_year}-{$m->request_month}",
					'text' => "{$monthName} {$m->request_year}"
				);
			}
			return $result;
		}

		public function get_all_sites($email, $status, $month, $order_key, $order_type, $current_page) {
			global $wpdb;

			$query = "SELECT * FROM {$this->get_table_name()}";
			$where = '';
			switch ($status) {
				case 'pending':
					$where .= ' created_date IS NULL AND close_date IS NULL ';
					break;
				case 'cancelled':
					$where .= ' created_date IS NULL AND close_date IS NOT NULL ';
					break;
				case 'running':
					$where .= ' created_date IS NOT NULL AND close_date IS NULL ';
					break;
				case 'closed':
					$where .= ' created_date IS NOT NULL AND close_date IS NOT NULL ';
					break;
			}
			if ($month !== '') {
				$month = explode('-', $month);
				if (count($month) === 2) {
					$year = $month[0];
					$month = $month[1];
					if ($where !== '') {
						$where .= ' AND ';
					}
					$where .= $wpdb->prepare(' month(request_date)=%d AND year(request_date)=%d', $month, $year);
				}
			}

			if ($email !== '') {
				if ($where !== '') {
					$where .= ' AND ';
				}
				$where .= $wpdb->prepare(' email=%s ', $email);
			}

			if ($where !== '') {
				$where = ' WHERE ' . $where;
			}

			$limit = $wpdb->prepare(' LIMIT %d, %d', ($current_page - 1) * CWSA()->page_size, CWSA()->page_size);

			$order_key = $order_key === '' ? 'request_date' : $order_key;
			$order_type = $order_type === 'asc' ? 'ASC' : 'DESC';

			$order_by = '';

			switch ($order_key) {
				case 'request_date':
					$order_by = " ORDER BY request_date {$order_type}, email ASC ";
					break;
				case 'create_date':
					$order_by = " ORDER BY created_date {$order_type}, email ASC ";
					break;
				case 'email':
					$order_by = " ORDER BY email {$order_type}, request_date DESC ";
					break;
			}

			return array(
				'items' => $wpdb->get_results($query . $where . $order_by . $limit),
				'total' => $wpdb->get_var("SELECT COUNT(*) FROM {$this->get_table_name()}" . $where),
			);
		}

		public function cancel_request($site_id) {
			global $wpdb;
			$result = $wpdb->query($wpdb->prepare("UPDATE {$this->get_table_name()} SET close_date = current_time() WHERE ID=%d AND created_date IS NULL AND close_date IS NULL", $site_id));
			return $result;
		}
	}
}