<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

add_filter( 'cron_schedules', 'cwsa_cron_for_delete_sandbox_schedule' );
function cwsa_cron_for_delete_sandbox_schedule( $schedules ) {
	// Add once 30 minutes to schedules
	$schedules['cwsa_schedule_timer'] = array(
		//'interval' => apply_filters('cwsa_schedule_timer', 1800),
		'interval' => apply_filters('cwsa_schedule_timer', 60),
		'display' => __( 'Delete Sandbox' ),
	);
	return $schedules;
}

register_activation_hook( CWSA_PLUGIN_FILE, 'cwsa_cron_to_delete_multisites_activation' );
function cwsa_cron_to_delete_multisites_activation() {
	if ( ! wp_next_scheduled( 'cwsa_check_multisites_hourly_event' ) ) {
		wp_schedule_event( time(), 'cwsa_schedule_timer', 'cwsa_check_multisites_hourly_event' );
	}
}

register_deactivation_hook( CWSA_PLUGIN_FILE, 'cwsa_cron_to_delete_multisites_deactivation' );
function cwsa_cron_to_delete_multisites_deactivation() {
	wp_clear_scheduled_hook( 'cwsa_check_multisites_hourly_event' );
}

add_action( 'cwsa_check_multisites_hourly_event', 'cwsa_check_multisites_for_deletion' );
function cwsa_check_multisites_for_deletion() {
	require_once( ABSPATH . 'wp-admin/includes/admin.php' );
	global $wpdb;
	$args = array(
		'network_id' => $wpdb->siteid,
	);

	$sites_arr  = get_sites( $args );
	$current_time = current_time( 'timestamp' );

	$time_to_delete = CWSA()->options()->get_time_to_delete() * 60; // minutes

	$site_default_for_clone = CWSA()->options()->get_site_default();

	foreach ( $sites_arr as $site ) {
		$blog_id = $site->blog_id;


		if (($blog_id == 1)
		    || ($blog_id == $site_default_for_clone)
			|| !CWSA()->db()->is_sandbox_site($blog_id)) {
			continue;
		}

		$register_time           = strtotime( $site->registered);
		$time_since_registration = $current_time - $register_time;

		$delete_this_site = apply_filters('cwsa_delete_site_cancel', true, $site);


		if ( $delete_this_site && ( $time_since_registration > $time_to_delete ) ) {
			if ( ! function_exists( 'wpmu_delete_blog' ) ) {
				return;
			}

			$site_info = CWSA()->db()->get_site_by_blog_id($blog_id);

			if ($site_info) {
				cwsa_delete_sandbox_site($site_info);
			}
		}
	}
}

function cwsa_delete_sandbox_site($site) {
	require_once( ABSPATH . 'wp-admin/includes/admin.php' );

	global $wpdb;

	CWSA()->db()->update($site->ID, array(
		'close_date' => cwsa_get_current_time()
	));

	$users     = get_users( array(
		'blog_id' => $site->blog_id,
		'fields'  => 'ID',
	) );

	/**
	 * Delete users
	 */
	foreach ( $users as $user_id ) {
		if( is_super_admin( $user_id ) ) {
			continue;
		}

		$all_blogs = get_blogs_of_user( $user_id );

		if ( count( $all_blogs ) <= 1 ) {
			wpmu_delete_user( $user_id );
		}
	}

	/**
	 * Delete blog
	 */
	wpmu_delete_blog( $site->blog_id, true );

	/**
	 * Delete other tables
	 */
	$_table_prefix = "{$wpdb->base_prefix}{$site->blog_id}_";
	$_tables = $wpdb->get_results( "SHOW TABLES LIKE '{$_table_prefix}%'", ARRAY_N );
	foreach ($_tables as $table_name) {
		$wpdb->query("DROP TABLE {$table_name[0]}");
	}

	/**
	 * Delete upload
	 */

	switch_to_blog($site->blog_id);
	$blog_upload_dir = cwsa_get_upload_dir($site->blog_id);
	restore_current_blog();

	cwsa_delete_files($blog_upload_dir);

	return true;
}