<?php
if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

add_action('wp_loaded', 'cwsa_create_sandbox_request_process');
function cwsa_create_sandbox_request_process() {
	if (!isset($_POST['cwsa_create_sandbox_request_nonce'])
	    || !wp_verify_nonce($_POST['cwsa_create_sandbox_request_nonce'], 'cwsa_create_sandbox_request_action')) {
		return;
	}

	if (apply_filters('adcs_cancel_create_sandbox', false)) {
		return;
	}

	$email = sanitize_email($_POST['email']);
	if ($email === '') {
		CWSA()->messages()->set_message('error',
			esc_html__('Sorry! You must enter your email for request create sandbox!','cwsa'),
			'error');
		return;
	}

	if (CWSA()->db()->check_site_active_by_email($email)) {
		CWSA()->messages()->set_message('error',
			wp_kses_post(__('Sorry! Your email has requested to create a sandbox site! <br/> The sandbox authentication link has been sent to your email. Thanks!.','cwsa')),
			'error');

		return;
	}

	if (get_user_by('email', $email)) {
		CWSA()->messages()->set_message('error',
			esc_html__('Sorry! This email is already exists. Please enter another email address! Thanks.','cwsa'),
			'error');
		return;
	}

	if (CWSA()->db()->get_active_site_amount() >= CWSA()->options()->get_limit_sandbox_site()) {
		CWSA()->messages()->set_message('error',
			esc_html__('Sorry! Sandbox site has reached the limit. Please try again later!','cwsa'),
			'error');
		return;
	}

	$email_list = CWSA()->options()->get_emails();
	$email_request_sandbox = isset($email_list['create-sandbox-request']['enable_email']) ? $email_list['create-sandbox-request']['enable_email'] : '';

	$authen_key = md5(uniqid('', true));

	if ($email_request_sandbox === 'on') {

		$result = CWSA()->db()->insert(array(
			'email' => $email,
			'authen_key' => $authen_key,
			'request_date' => cwsa_get_current_time()
		));

		if ($result === false) {
			CWSA()->messages()->set_message('error',
				esc_html__('Sorry! An error occurred. Please try again!','cwsa'),
				'error');
			return;
		}

		CWSA()->email()->request_create_sandbox(array(
			'user_email' => $email,
			'authen_link' => home_url('/') . '?cwsa_authen_key=' . $authen_key
		));

		CWSA()->messages()->set_message('success',
			esc_html__('Request successful sandbox site creation! The sandbox authentication link has been sent to your email. Eamil can take a few minutes to get into your inbox. Thanks.','cwsa'),
			'success');

		wp_redirect(cwsa_get_request_sandbox_page_url());
		die();
	}
	else {
		$result = CWSA()->db()->insert(array(
			'email' => $email,
			'authen_key' => $authen_key,
			'request_date' => cwsa_get_current_time(),
			'created_date' => cwsa_get_current_time(),
		));

		if ($result === false) {
			CWSA()->messages()->set_message('error',
				esc_html__('Sorry! An error occurred. Please try again!','cwsa'),
				'error');
			return;
		}

		$site = CWSA()->db()->get_site_by_authen_key($authen_key);

		cwsa_create_sandbox_site($authen_key, $site);

	}
}

add_action('init', 'cwsa_create_sandbox_authen', 0);
function cwsa_create_sandbox_authen() {
	if (!isset($_GET['cwsa_authen_key'])) {
		return;
	}

	$authen_key = $_GET['cwsa_authen_key'];
	if (strlen($authen_key) !== 32) {
		wp_redirect(home_url('/'));
		die();
	}

	$site = CWSA()->db()->get_site_by_authen_key($authen_key);

	cwsa_create_sandbox_site($authen_key, $site);
}

/**
 * Create sandbox site
 *
 * @param $authen_key
 * @param $site
 */
function cwsa_create_sandbox_site($authen_key, $site) {
	if ($site === null) {
		wp_redirect(home_url('/'));
		die();
	}

	if ($site->close_date !== null) {
		CWSA()->messages()->set_message('error',
			wp_kses(__('Sorry! Authentication key to sandbox site has expired! <br/> Please enter your email to create new sandbox site!','cwsa'), array('br' => '')),
			'error');
		wp_redirect(cwsa_get_request_sandbox_page_url());
		die();
	}
	if (($site->created_date !== null) && ($site->blog_id !== null)) {
		$user_info = get_user_by( 'email', $site->email );
		$blog_site_url =  get_site_url( $site->blog_id );

		wp_set_auth_cookie( $user_info->ID );
		wp_redirect($blog_site_url.'/wp-admin/admin.php?page=catalog_mode');
		die();
	}

	do_action('cwsa_create_sandbox_site_before');

	$username = $authen_key ;
	$email = $site->email;
	$password =  'demo';

	$user_id = wpmu_create_user( $username, $password, $email );

	if( is_wp_error( $user_id ) ){
		CWSA()->messages()->set_message('error',
			esc_html__('Sorry! Creating user for sandbox site failed!','cwsa'),
			'error');
		wp_redirect(cwsa_get_request_sandbox_page_url());
		die();
	}

	$main_site = DOMAIN_CURRENT_SITE;
	$sandbox_prefix = CWSA()->options()->get_sandbox_site_prefix();

	$site_name = uniqid();
	$new_site = "{$sandbox_prefix}{$site_name}";


	if( is_subdomain_install() ) {
		$newdomain = "{$new_site}.$main_site";
		$path = '/';
	} else {
		$newdomain = $main_site;
		$path = PATH_CURRENT_SITE . "{$new_site}/";
	}

	// Create the new sub-site
	$title = esc_html__('Sandbox For ','cwsa') . "\"{$email}\"";
	$blog_id = wpmu_create_blog( $newdomain, $path, $title, $user_id , array( 'public' => 1 ) );

	if( is_wp_error( $blog_id ) ){
		CWSA()->messages()->set_message('error',
			esc_html__('Sorry! Creating sandbox site failed!','cwsa'),
			'error');
		wp_redirect(cwsa_get_request_sandbox_page_url());
		die();
	}

	CWSA()->db()->update($site->ID, array(
		'created_date' => cwsa_get_current_time(),
		'blog_id' => $blog_id,
	));

	CWSA_Emails_Create_Sandbox_Notify_Admin::get_instance()->send_email(array(
		'blog_id' => $blog_id,
		'user_email' => $email,
		'request_date' => $site->request_date,
	));

	do_action('cwsa_create_sandbox_site_done', $blog_id, $user_id);

	$blog_site_url =  get_site_url( $blog_id );

	wp_set_auth_cookie( $user_id );

	wp_redirect($blog_site_url.'/wp-admin/admin.php?page=catalog_mode');
	die();
}

add_action('wp_loaded', 'cwsa_create_page_request_sandbox_handler');
function cwsa_create_page_request_sandbox_handler() {
	if (!isset($_POST['cwsa_create_page_request_sandbox_nonce'])
	    || !wp_verify_nonce($_POST['cwsa_create_page_request_sandbox_nonce'], 'cwsa_create_page_request_sandbox_action')) {
		return;
	}

	$page_title = sanitize_text_field($_POST['page_title']);
	$page_id = wp_insert_post(array(
		'post_title' => $page_title,
		'post_status' => 'publish',
		'post_type' => 'page',
		'post_content' => '[cwsa_create_sandbox_request]',
	));

	if (is_wp_error($page_id)) {
		cwsa_admin_message_add(esc_html__('Sorry! An error occurred during page creation!','cwsa'), 'error');
		return;
	}

	CWSA()->options()->set_value('request_sandbox_page', $page_id);
	CWSA()->options()->update();
	cwsa_admin_message_add(esc_html__('Create Request Sandbox Page Done!','cwsa'), 'success');
}
