<?php
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

if (!class_exists('CWSA_Install')) {
    class CWSA_Install
    {
        private static $_instance;
        public static function getInstance()
        {
            if (self::$_instance == null) {
                self::$_instance = new self();
            }
            return self::$_instance;
        }

        public function init()
        {
            add_action('init', array($this, 'check_update'));
        }

        public function check_update()
        {
            if (!defined('IFRAME_REQUEST') && (get_option('cwsa_version') !== CWSA()->plugin_version())) {
	            $this->install();
	            do_action('cwsa_updated');
            }
        }

        public function install()
        {
            if (!is_blog_installed()) {
                return;
            }

            if ('yes' === get_transient('cwsa_installing')) {
                return;
            }

            set_transient('cwsa_installing', 'yes', MINUTE_IN_SECONDS * 10);
            if (!defined('CWSA_INSTALLING')) {
                define('CWSA_INSTALLING', true);
            }

            $this->create_tables();
            $this->update_plugin_version();

            delete_transient('cwsa_installing');
            do_action('cwsa_installed');
        }

        /**
         * Create table for plugin
         */
        public function create_tables()
        {
            require_once(ABSPATH . 'wp-admin/includes/upgrade.php');

            global $wpdb;
            $table_prefix = "{$wpdb->base_prefix}cwsa_";

            $charset_collate = '';
            if ($wpdb->has_cap('collation')) {
                $charset_collate = $wpdb->get_charset_collate();
            }


	        $table_name = $table_prefix . 'settings';
	        $sql = "CREATE TABLE {$table_name} (
                        ID bigint(20) NOT NULL AUTO_INCREMENT,
                        setting_key varchar(200) NOT NULL,
                        setting_value longtext NULL,
                        PRIMARY KEY  (ID)
                        ) {$charset_collate};
                        ";
	        dbDelta($sql);

            $table_name = $table_prefix . 'site';
            $sql = "CREATE TABLE {$table_name} (
                        ID mediumint(9) NOT NULL AUTO_INCREMENT,
                        email varchar(200) NOT NULL,
                        authen_key varchar(200) NOT NULL,
                        request_date datetime NOT NULL,
                        blog_id bigint(20) NULL,
                        created_date datetime NULL,
                        close_date datetime NULL,
                        PRIMARY KEY  (ID)
                        ) {$charset_collate};
                        ";
            dbDelta($sql);
        }

        /**
         * Update plugin version
         */
        public function update_plugin_version()
        {
            update_option('cwsa_version', CWSA()->plugin_version());
        }

    }
}