<?php
if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

if (!class_exists('CWSA_Math_Captcha')) {
	class CWSA_Math_Captcha {
		private static $_instance;
		public static function get_instance()
		{
			if (self::$_instance == NULL) {
				self::$_instance = new self();
			}

			return self::$_instance;
		}

		public function init() {
			add_action('init', array($this, 'render_captcha'));
			add_action('cwsa_create_sandbox_request_email_after', array($this, 'math_captcha_field'));
			add_filter('adcs_cancel_create_sandbox', array($this, 'validate'));
		}

		public function render_captcha() {
			if (!isset($_GET['cwsa_captcha_nonce']) || !wp_verify_nonce($_GET['cwsa_captcha_nonce'], 'cwsa_captcha_action')) {
				return;
			}
			cwsa_session_start();
			$number1 = rand(1, 9);
			$number2 = rand(1, 9);
			$operator = rand(1, 2);

			$operator = ($operator === 1) ? '+' : '-';

			switch ($operator) {
				case '+':
					$total = $number1 + $number2;
					$num_str = $number1 . ' + ' . $number2 . ' =';
					break;
				case '-':
					$number1 = rand(2, 9);
					$number2 = rand(1, $number1);

					$total = $number1 - $number2;
					$num_str = $number1 . ' - ' . $number2 . ' =';
					break;
			}

			$_SESSION['cwsa_captcha'] = $total;

			$width = apply_filters('cwsa_math_captcha_width', 180);
			$height = apply_filters('cwsa_math_captcha_height', 48);
			$font_size = apply_filters('cwsa_math_captcha_font_size', 24);
			$position_x = apply_filters('cwsa_math_captcha_x', 35);

			$img = imagecreate( $width, $height );

			$background = imagecolorallocate( $img, 206, 212, 218 );

			$text_color = imagecolorallocate( $img, 44, 44, 44 );

			$font_file = CWSA()->plugin_dir('assets/fonts/SpecialElite-Regular.ttf');

			imagettftext($img, $font_size, 0, $position_x, floor(($height + $font_size)/2), $text_color, $font_file, $num_str);

			header( 'Content-type: image/png' );
			imagepng( $img );
			imagecolordeallocate( $img, $text_color );
			imagecolordeallocate( $img, $background );
			imagedestroy( $img );
			die();
		}

		public function math_captcha_field() {
			if (CWSA()->options()->get_captcha_type() === 'math_captcha') {
				cwsa_get_template('math-captcha-field.php');
			}
		}

		public function validate($cancel) {
			if (CWSA()->options()->get_captcha_type() === 'math_captcha') {
				$captcha = $_POST['math_captcha'];

				if (!isset($_SESSION['cwsa_captcha']) || ($captcha != $_SESSION['cwsa_captcha'])) {
					$cancel = true;
					CWSA()->messages()->set_message('error',
						esc_html__( 'Sorry! Please enter the correct result! Thanks.','cwsa'),
						'error');
				}
			}

			return $cancel;
		}
	}
}