<?php
if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

if (!class_exists('CWSA_Options')) {
	class CWSA_Options {
		private static $_instance;
		public static function get_instance()
		{
			if (self::$_instance == NULL) {
				self::$_instance = new self();
			}

			return self::$_instance;
		}

		private $_settings = array();

		public function __construct() {
			$this->_settings = $this->get_setting('settings');

		}

		private function get_setting($key) {
			global $wpdb;
			$table_name = "{$wpdb->base_prefix}cwsa_settings";
			$v = $wpdb->get_var($wpdb->prepare("SELECT setting_value FROM {$table_name} WHERE setting_key=%s", $key));
			if ($v === null) {
				return null;
			}
			if (is_serialized($v)) {
				$v = unserialize($v);
			}
			return $v;
		}

		private function update_setting($key, $value) {
			global $wpdb;

			if ($this->get_setting($key) === null) {
				return $this->insert_settings($key, $value);
			}

			$table_name = "{$wpdb->base_prefix}cwsa_settings";

			if (is_array($value) || is_object($value)) {
				$value = serialize($value);
			}

			return $wpdb->query($wpdb->prepare("UPDATE {$table_name} SET setting_value=%s WHERE setting_key=%s", $value, $key));
		}

		private function insert_settings($key, $value) {
			global $wpdb;
			$table_name = "{$wpdb->base_prefix}cwsa_settings";

			if (is_array($value) || is_object($value)) {
				$value = serialize($value);
			}
			return $wpdb->query($wpdb->prepare("INSERT INTO {$table_name}(setting_key,setting_value) VALUES(%s,%s)", $key, $value));
		}

		public function set_value($key, $value) {
			$this->_settings[$key] = $value;
		}

		public function get_value($key, $default = '') {
			return isset($this->_settings[$key]) ? $this->_settings[$key] : $default;
		}

		public function update() {
			$this->update_setting('settings', $this->_settings);
		}

		public function get_site_default() {
			return $this->get_value('site_default');
		}
		public function get_time_to_delete() {
			return $this->get_value('time_to_delete', 60);
		}
		public function get_sandbox_site_prefix() {
			return $this->get_value('sandbox_site_prefix', 'demo');
		}
		public function get_limit_sandbox_site() {
			return $this->get_value('limit_sandbox_site', 50);
		}
		public function get_sandbox_user_role() {
			return $this->get_value('sandbox_user_role', 'administrator');
		}
		public function get_auto_assign_supper_admin() {
			return $this->get_value('auto_assign_supper_admin');
		}
		public function get_request_sandbox_page() {
			return $this->get_value('request_sandbox_page');
		}
		public function get_captcha_type() {
			return $this->get_value('captcha_type', 'math_captcha');
		}
		public function get_email_from_name() {
			return $this->get_value('email_from_name', get_bloginfo('name'));
		}
		public function get_email_from_address() {
			return $this->get_value('email_from_address', get_bloginfo('admin_email'));
		}
		public function get_email_footer_text() {
			$site_name = cwsa_get_site_name();

			return $this->get_value('email_footer_text', "{$site_name} - Powered by CWSA");
		}
		public function get_emails() {
			return $this->get_value('emails', array());
		}
	}
}