<?php
if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}
if (!class_exists('CWSA_Sandbox_Timer')) {
	class CWSA_Sandbox_Timer
	{
		private static $_instance;
		public static function getInstance()
		{
			if (self::$_instance == null) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}

		public function init() {
			add_action( 'init', array( $this, 'register_scripts' ) );
			add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
			add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_scripts' ) );

			add_action( 'init', array($this, 'check_site_running'), 0);
		}

		public function check_site_running() {
			$details = get_blog_details(get_current_blog_id());

			$register_time = strtotime($details->registered);
			$current_time = current_time( 'timestamp' );

			$time_since_registration = $current_time - $register_time;

			$time_to_delete = CWSA()->options()->get_time_to_delete();

			if ($time_since_registration >  $time_to_delete * 60) {
				switch_to_blog(1);
				$main_url = get_permalink(CWSA()->options()->get_request_sandbox_page());
				restore_current_blog();
				wp_redirect($main_url);
				die();
			}
		}

		public function register_scripts() {
			wp_register_script( cwsa_get_assets_handle( 'sandbox-timer' ), cwsa_get_asset_url( 'assets/js/sandbox-timer.min.js' ), array( 'jquery' ), cwsa_get_plugin_version(), true );
			wp_register_style( cwsa_get_assets_handle( 'timer' ), cwsa_get_asset_url( 'assets/css/timer.min.css' ), array(), cwsa_get_plugin_version() );
		}

		public function enqueue_scripts() {
			wp_enqueue_style( cwsa_get_assets_handle( 'timer' ));
			wp_enqueue_script( cwsa_get_assets_handle( 'sandbox-timer' ) );

			$details = get_blog_details(get_current_blog_id());
			$register_time = strtotime($details->registered);
			$current_time = current_time( 'timestamp' );

			$time_to_delete = CWSA()->options()->get_time_to_delete();

			$remain_time = ($time_to_delete * 60) - ($current_time - $register_time) - 1;
			if ($remain_time < 0) {
				$remain_time = 0;
			}

			$main_url = home_url('/');
			if (CWSA()->options()->get_site_default() !== '') {
				switch_to_blog(1);
				$main_url = get_permalink(CWSA()->options()->get_request_sandbox_page());
				restore_current_blog();
			}

			wp_localize_script(cwsa_get_assets_handle( 'sandbox-timer' ), 'CWSA_VAR', array(
				'remain_time' => $remain_time,
				'main_url' => $main_url,
				'timer_text' => esc_html__('Time remaining:','cwsa')
			));
		}

	}
}