<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
/**
 * @var $current_tab string
 */
$section = isset($_GET['section']) ? $_GET['section'] : '';
$email_notification_list = cwsa_email_notification_list();
if (!in_array($section, array_keys($email_notification_list))) {
	$section = '';
}
?>
<form method="post" action="">
	<?php if ($section !== ''): ?>
		<h2> <?php echo $email_notification_list[$section]['name'] ?>
			<small class="wc-admin-breadcrumb">
				<a href="<?php echo esc_url('admin.php?page=cwsa-settings&tab=email') ?>" aria-label="<?php echo esc_attr__('Return to emails','cwsa') ?>">⤴</a>
			</small>
		</h2>
		<input type="hidden" name="section" value="<?php echo esc_attr($section) ?>">
		<?php cwsa_get_admin_template("email/{$section}.php", array('current_section' => $section, '')); ?>
	<?php else: ?>
		<?php
		$email_from_name = CWSA()->options()->get_email_from_name();
		$email_from_address = CWSA()->options()->get_email_from_address();
		$email_footer_text = CWSA()->options()->get_email_footer_text();
		$email_list = CWSA()->options()->get_emails();
		?>
		<h2><?php echo esc_html__( 'Email sender options', 'cwsa' ) ?></h2>
		<table class="form-table" role="presentation">
			<tbody>
			<tr>
				<th scope="row">
					<label for="email_from_name"><?php echo esc_html__( '"From" name', 'cwsa' ) ?></label>
				</th>
				<td>
					<input id="email_from_name" name="email_from_name" class="regular-text"
					       type="text" value="<?php echo esc_attr( $email_from_name ) ?>">
				</td>
			</tr>

			<tr>
				<th scope="row">
					<label for="email_from_address"><?php echo esc_html__( '"From" address', 'cwsa' ) ?></label>
				</th>
				<td>
					<input id="email_from_address" name="email_from_address" class="regular-text"
					       type="email" value="<?php echo esc_attr( $email_from_address ) ?>">
				</td>
			</tr>
			</tbody>
		</table>

		<h2><?php echo esc_html__( 'Email template', 'cwsa' ) ?></h2>
		<p><?php echo esc_html__('This section lets you customize the Plugin emails.','cwsa') ?>
			<a href="<?php echo esc_url(wp_nonce_url(admin_url('admin.php'), 'cwsa_view_email_template_action', 'cwsa_view_email_template_nonce')) ?>" target="_blank"><?php echo esc_html__('Click here to preview your email template','cwsa') ?></a>.
		</p>
		<table class="form-table" role="presentation">
			<tbody>
			<tr>
				<th scope="row">
					<label for="email_footer_text"><?php echo esc_html__( 'Footer Text', 'cwsa' ) ?></label>
				</th>
				<td>
					<textarea name="email_footer_text" id="email_footer_text" cols="30" rows="5" class="regular-text"><?php echo esc_textarea( $email_footer_text ) ?></textarea>
				</td>
			</tr>
			</tbody>
		</table>

		<h2><?php echo esc_html__( 'Email notifications', 'cwsa' ) ?></h2>
		<p><?php echo esc_html__( 'Email notifications sent from Create WordPress Sandbox Automatic are listed below. Click on an email to configure it.', 'cwsa' ) ?></p>
		<table class="wp-list-table widefat fixed striped" cellspacing="0">
			<thead>
			<tr>
				<th class="cwsa-col-email-status"></th>
				<th><?php echo esc_html__('Email','cwsa') ?></th>
				<th class="cwsa-col-email-recipient"><?php echo esc_html__('Recipient(s)','cwsa') ?></th>
				<th class="cwsa-col-email-action"></th>
			</tr>
			</thead>
			<tbody>
			<?php foreach (cwsa_email_notification_list() as $em_key => $em): ?>
				<?php
				$email_info = isset($email_list[$em_key]) ? $email_list[$em_key] : array();
				$em_status = 'cwsa-email-status-disabled';
				$em_status_text = esc_html__('Disabled','cwsa');
				if (isset($email_info['enable_email']) && ($email_info['enable_email'] === 'on')) {
					$em_status = 'cwsa-email-status-enabled';
					$em_status_text = esc_html__('Enabled','cwsa');
				}
				$recipients = esc_html__('User','cwsa');
				if (($em['recipient'] === 'admin')) {
					$recipients = isset($email_info['recipients']) ? $email_info['recipients'] : get_bloginfo('admin_email');
					if ($recipients === '') {
						$recipients = get_bloginfo('admin_email');
					}
				}

				?>
				<tr>
					<td><span class="cwsa-email-status cwsa-tips <?php echo esc_attr($em_status) ?>" data-tip="<?php echo esc_attr($em_status_text) ?>"></span></td>
					<td>
						<a href="<?php echo esc_url(admin_url('admin.php?page=cwsa-settings&tab=email&section=' . $em_key)) ?>">
							<?php echo esc_html($em['name']) ?>
							<?php if (isset($em['desc']) && !empty($em['desc'])): ?>
								<p class="description"><?php echo esc_html($em['desc'])?></p>
							<?php endif; ?>
						</a>
					</td>
					<td>
						<?php echo esc_html($recipients) ?>
					</td>
					<td>
						<a class="button alignright" href="<?php echo esc_url(admin_url('admin.php?page=cwsa-settings&tab=email&section=' . $em_key)) ?>"><?php echo esc_html__('Manage','cwsa') ?></a>
					</td>
				</tr>
			<?php endforeach; ?>
			</tbody>
		</table>
	<?php endif; ?>

	<?php cwsa_get_template('admin/settings-submit.php', array('current_tab' => $current_tab)); ?>
</form>