<?php
if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

$site_default = CWSA()->options()->get_site_default();
$time_to_delete = CWSA()->options()->get_time_to_delete();
$sandbox_site_prefix = CWSA()->options()->get_sandbox_site_prefix();
$limit_sandbox_site = CWSA()->options()->get_limit_sandbox_site();
$sandbox_user_role = CWSA()->options()->get_sandbox_user_role();
$auto_assign_supper_admin = CWSA()->options()->get_auto_assign_supper_admin();
$request_sandbox_page = CWSA()->options()->get_request_sandbox_page();
$captcha_type = CWSA()->options()->get_captcha_type();
?>
<form method="post" action="">
	<table class="form-table">
		<tbody>
		<tr>
			<th scope="row">
				<label for="site_default"><?php echo esc_html__('Site Default For Cloning', 'cwsa') ?></label>
			</th>
			<td>
				<select id="site_default" name="site_default">
					<?php foreach (cwsa_get_sites() as $st_id => $st_title): ?>
						<option value="<?php echo esc_attr($st_id) ?>" <?php selected($site_default, $st_id) ?>><?php echo esc_html($st_title) ?></option>
					<?php endforeach; ?>
				</select>
				<p class="description"><?php echo esc_html__('Select default Site for cloning when creating a new Site', 'cwsa') ?></p>
			</td>
		</tr>
		<tr>
			<th scope="row">
				<label for="sandbox_user_role"><?php echo esc_html__('Sandbox User Role', 'cwsa') ?></label>
			</th>
			<td>
				<select id="sandbox_user_role" name="sandbox_user_role">
					<?php foreach (cwsa_get_all_roles() as $role_key => $role_value): ?>
						<option value="<?php echo esc_attr($role_key) ?>" <?php selected($sandbox_user_role, $role_key) ?>><?php echo esc_html($role_value) ?></option>
					<?php endforeach; ?>
				</select>
				<p class="description"><?php echo esc_html__('This is the role new sandbox users will have.', 'cwsa') ?></p>
			</td>
		</tr>
		<tr valign="top">
			<th>
				<label for="auto_assign_supper_admin"><?php echo esc_html__('Assign Supper Admin to the sandbox site','cwsa') ?></label>
			</th>
			<td>
				<fieldset>
					<label for="auto_assign_supper_admin">
						<input class="" type="checkbox"
						       name="auto_assign_supper_admin" id="auto_assign_supper_admin"
						       <?php checked($auto_assign_supper_admin, 'on') ?>
						       value="on">
						<?php echo esc_html__('Enable/Disable assign Supper Admin','cwsa') ?>
					</label>
					<p class="description"><?php echo esc_html__('Turn on this feature to allow assign Supper Admin account to the sandbox site when created!','dirplus') ?></p>
				</fieldset>
			</td>
		</tr>
		<tr>
			<th scope="row">
				<label for="request_sandbox_page"><?php echo esc_html__('Create Sandbox Page', 'cwsa') ?></label>
			</th>
			<td class="cwsa-create-page-wrap">
				<div class="cwsa-create-page-inner">
					<select id="request_sandbox_page" name="request_sandbox_page">
						<?php foreach (cwsa_get_all_pages() as $p_ID => $p_title): ?>
							<option value="<?php echo esc_attr($p_ID) ?>" <?php selected($request_sandbox_page, $p_ID) ?>><?php echo esc_html($p_title) ?></option>
						<?php endforeach; ?>
					</select>
					<?php echo esc_html__('or', 'cwsa') ?>
					<a href="<?php echo esc_url(wp_nonce_url(admin_url('admin-ajax.php?action=cwsa_create_page_request_sandbox_form'), 'cwsa_create_page_request_sandbox_form_action', 'cwsa_create_page_request_sandbox_form_nonce')) ?>"
					   class="cwsa-create-new-page">
						<?php echo esc_html__('Create new page', 'cwsa') ?>
					</a>
				</div>

				<p class="description"><?php echo esc_html__('Request Sandbox Page contains shortcode "[cwsa_create_sandbox_request]"', 'cwsa') ?></p>
			</td>
		</tr>
		<tr>
			<th scope="row">
				<label for="time_to_delete"><?php echo esc_html__('Time to delete site', 'cwsa') ?></label>
			</th>
			<td>
				<input id="time_to_delete" name="time_to_delete" type="number"
				       step="1" min="1" max="120" value="<?php echo esc_attr($time_to_delete) ?>"
				       class="small-text">
				(<?php echo esc_html__('minutes', 'cwsa') ?>)
			</td>
		</tr>
		<tr>
			<th scope="row">
				<label for="sandbox_site_prefix"><?php echo esc_html__('Sandbox site prefix', 'cwsa') ?></label>
			</th>
			<td>
				<input id="sandbox_site_prefix" name="sandbox_site_prefix" type="text"
				       value="<?php echo esc_attr($sandbox_site_prefix) ?>">
			</td>
		</tr>
		<tr>
			<th scope="row">
				<label for="limit_sandbox_site"><?php echo esc_html__('Limit Sandbox Site', 'cwsa') ?></label>
			</th>
			<td>
				<input id="limit_sandbox_site" name="limit_sandbox_site" type="text"
				       value="<?php echo esc_attr($limit_sandbox_site) ?>">
				(<?php echo esc_html__('sites', 'cwsa') ?>)
			</td>
		</tr>
		<tr>
			<th scope="row">
				<label for="captcha_type"><?php echo esc_html__('Captcha Type', 'cwsa') ?></label>
			</th>
			<td>
				<select id="captcha_type" name="captcha_type">
					<?php foreach (cwsa_get_captcha_list() as $c_key => $c_value): ?>
						<option value="<?php echo esc_attr($c_key) ?>" <?php selected($captcha_type, $c_key) ?>><?php echo esc_html($c_value) ?></option>
					<?php endforeach; ?>
				</select>
				<p class="description"><?php echo esc_html__('Do not select any type to disable captcha for sandbox creation request!!', 'cwsa') ?></p>
			</td>
		</tr>
		</tbody>
	</table>

	<?php cwsa_get_template('admin/settings-submit.php', array('current_tab' => $current_tab)); ?>
</form>