<?php
if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}
/**
 * @var $current_tab string
 */
$email = isset($_GET['email']) ? sanitize_text_field($_GET['email']) : '';
$filter_status = isset($_GET['filter_status']) ? sanitize_text_field($_GET['filter_status']) : '';
$filter_month = isset($_GET['filter_month']) ? sanitize_text_field($_GET['filter_month']) : '';
$order_key = isset($_GET['order_key']) ? sanitize_text_field($_GET['order_key']) : '';
$order_type = isset($_GET['order_type']) ? sanitize_text_field($_GET['order_type']) : 'desc';
$current_page = isset($_GET['paged']) ? sanitize_text_field($_GET['paged']) : '1';

$sites = CWSA()->db()->get_all_sites($email, $filter_status, $filter_month,$order_key,$order_type,$current_page);

$current_url = remove_query_arg('id', cwsa_get_current_url());
$action_nonce_url = wp_nonce_url($current_url, 'cwsa_register_management_action', 'cwsa_register_management_nonce');
?>
<h2 class="wp-heading-inline"><?php echo esc_html__('Customers Register', 'cwsa') ?></h2>
<?php cwsa_get_template('admin/register-management/filter-status.php'); ?>
<form method="get" action="" id="cwsa_form_register_management">
	<input type="hidden" name="page" value="cwsa-settings">
	<input type="hidden" name="tab" value="register-management">
	<?php wp_nonce_field('cwsa_register_management_action', 'cwsa_register_management_nonce') ?>
	<?php cwsa_get_template('admin/register-management/search-box.php'); ?>
	<div class="tablenav top cwsa-tablenav">
		<?php cwsa_get_template('admin/register-management/action.php'); ?>
		<?php cwsa_get_template('admin/register-management/filter.php'); ?>
		<?php cwsa_get_template('admin/register-management/pagination.php', array('total_item' => $sites['total'])); ?>
		<br class="clear">
	</div>
	<table class="wp-list-table widefat fixed striped posts">
		<thead>
		<?php cwsa_get_template('admin/register-management/table-header.php'); ?>
		</thead>

		<tbody id="the-list">
		<?php if ($sites['total'] > 0): ?>
			<?php foreach ($sites['items'] as $item): ?>
				<?php
				$status = cwsa_get_site_status($item);
				$action_url = add_query_arg('site_id', $item->ID, $action_nonce_url);
				?>
				<tr id="customer-<?php echo esc_attr($item->ID) ?>">
					<th scope="row" class="check-column">
						<input id="cb-select-<?php echo esc_attr($item->ID) ?>" type="checkbox" name="sites[]" value="<?php echo esc_attr($item->ID) ?>">
					</th>
					<td class="title column-title has-row-actions column-primary page-title" data-colname="<?php echo esc_attr__('Authentication Key','cwsa') ?>">
						<div class="locked-info"><span class="locked-avatar"></span> <span class="locked-text"></span></div>
						<strong>
							<?php if (($status['status'] === 'pending') || ($status['status'] === 'running')): ?>
								<a class="row-title"
								   target="_blank"
								   href="<?php echo esc_url(add_query_arg('cwsa_authen_key', $item->authen_key, home_url('/'))) ?>">
									<?php echo esc_html($item->authen_key) ?>
								</a>
							<?php else: ?>
								<span><?php echo esc_html($item->authen_key) ?></span>
							<?php endif; ?>
						</strong>
						<div class="row-actions">
							<?php if ($status['status'] === 'pending'): ?>
								<span class="trash">
								<a href="<?php echo esc_url(add_query_arg('action','cancel', $action_url)) ?>"
								   data-cwsa-confirm="<?php echo esc_attr__('Do you want to cancel this request?','cwsa') ?>">
									<?php echo esc_html__('Cancel Request','cwsa') ?>
								</a> |
							</span>
								<span>
								<a href="<?php echo esc_url(add_query_arg('action','resend', $action_url)) ?>">
									<?php echo esc_html__('Resend Email','cwsa') ?>
								</a> |
							</span>
							<?php endif; ?>
							<?php if ($status['status'] === 'running'): ?>
								<span class="trash">
									<a href="<?php echo esc_url(add_query_arg('action','drop', $action_url)) ?>"
									   data-cwsa-confirm="<?php echo esc_attr__('Do you want to delete this sandbox?','cwsa') ?>">
										<?php echo esc_html__('Drop Sandbox','cwsa') ?>
									</a> |
								</span>
							<?php endif; ?>
							<?php if ($status['status'] === 'running'): ?>
								<span>
									<a href="<?php echo esc_url(get_admin_url($item->blog_id)) ?>">
										<?php echo esc_html__('Dashboard','cwsa') ?>
									</a> |
								</span>
							<?php endif; ?>
							<?php if (($status['status'] === 'pending') || ($status['status'] === 'running')): ?>
								<span>
									<a href="<?php echo esc_url(add_query_arg('cwsa_authen_key', $item->authen_key, home_url('/'))) ?>" rel="bookmark"><?php echo esc_html__('View','cwsa') ?></a>
								</span>
							<?php endif; ?>
						</div>
						<button type="button" class="toggle-row">
							<span class="screen-reader-text"><?php echo esc_html__('Show more details','cwsa') ?></span>
						</button>
					</td>
					<td class="author column-author" data-colname="<?php echo esc_attr__('Customer','cwsa') ?>">
						<a href="<?php echo esc_url(admin_url('admin.php?page=cwsa-settings&tab=register-management&email=' . $item->email)) ?>">
							<?php echo esc_html($item->email) ?>
						</a>
					</td>
					<td class="date column-date" data-colname="<?php echo esc_attr__('Request Date','cwsa') ?>">
						<span><?php echo date('F j, Y', strtotime($item->request_date))  ?></span><br>
						<span><?php echo date('g:i:s A', strtotime($item->request_date))  ?></span>
					</td>
					<td class="date column-date" data-colname="<?php echo esc_attr__('Create Date','cwsa') ?>">
						<?php if ($item->created_date !== null): ?>
							<span><?php echo date('F j, Y', strtotime($item->created_date))  ?></span><br>
							<span><?php echo date('g:i:s A', strtotime($item->created_date))  ?></span>
						<?php else: ?>
							<span>—</span>
						<?php endif; ?>
					</td>
					<td class="categories column-categories" data-colname="Status">
						<a href="<?php echo esc_url(admin_url('admin.php?page=cwsa-settings&tab=register-management&filter_status=' . $status['status'])) ?>">
							<?php echo esc_html($status['text']) ?>
						</a>
					</td>
				</tr>
			<?php endforeach; ?>
		<?php else: ?>
			<tr>
				<td colspan="6"><?php echo esc_html__('No items','cwsa')?></td>
			</tr>
		<?php endif; ?>

		</tbody>
		<tfoot>
		<?php cwsa_get_template('admin/register-management/table-header.php'); ?>
		</tfoot>
	</table>
</form>